@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
+"""
+cdec                US/CA station I,H,D,M: California Department of Water
+                    Resources
+"""
+
+import datetime
 import warnings
+from pathlib import Path
 from typing import Optional, Union
 
 import pandas as pd
-from mando import command
-from tstoolbox import tsutils
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
-
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
+__all__ = ["cdec"]
 
 dur_code_map = {
     "daily": "D",
@@ -36,187 +33,53 @@ fname_code_map = {
 }
 
 sensor_num_map = {
-    "river stage": 1,
+    "river_stage": 1,
     "stage": 1,
     "precipitation": 2,
     "swe": 3,
-    "snow water equivalent": 3,
-    "air temperature": 4,
+    "snow_water_equivalent": 3,
+    "air_temperature": 4,
     "ec": 5,
-    "reservoir elevation": 6,
-    "reservoir scheduled release": 7,
-    "full natural flow:cfs": 8,
-    "reservoir storage": 15,
+    "reservoir_elevation": 6,
+    "reservoir_scheduled_release": 7,
+    "full_natural_flow:cfs": 8,
+    "reservoir_storage": 15,
     "flow": 20,
-    "reservoir storage change": 22,
-    "reservoir outflow": 23,
+    "reservoir_storage_change": 22,
+    "reservoir_outflow": 23,
     "evapotranspiration": 24,
-    "water temperature": 25,
-    "water turbidity": 27,
+    "water_temperature": 25,
+    "water_turbidity": 27,
     "turbidity": 27,
     "chlorophyll": 28,
-    "flow daily": 41,
+    "flow_daily": 41,
     "precipitation incremental": 45,
-    "runoff volume": 46,
-    "dissolved oxygen": 61,
-    "water dissolved oxygen": 61,
+    "runoff_volume": 46,
+    "dissolved_oxygen": 61,
+    "water_dissolved_oxygen": 61,
     "do": 61,
     "ph": 62,
-    "pan evaporation": 64,
-    "full natural flow: acre ft": 65,
-    "flow monthly": 66,
+    "pan_evaporation": 64,
+    "full_natural_flow:acre_ft": 65,
+    "flow_monthly": 66,
     "accretions": 67,
-    "spillway discharge": 71,
-    "spillway flow": 71,
-    "lake evaporation": 74,
+    "spillway_discharge": 71,
+    "spillway_flow": 71,
+    "lake_evaporation": 74,
     "evaporation": 74,
-    "reservoir inflow": 76,
-    "control regulating discharge": 85,
-    "top conservation storage": 94,
-    "water ec": 100,
+    "reservoir_inflow": 76,
+    "control_regulating_discharge": 85,
+    "top_conservation_storage": 94,
+    "water_ec": 100,
 }
 
 
-@command("cdec", formatter_class=HelpFormatter, doctype="numpy")
-@tsutils.doc(tsutils.docstrings)
-def cdec_cli(
-    station_id, dur_code=None, sensor_num=None, start_date=None, end_date=None
-):
-    r"""US/CA station E,H,D,M: California Department of Water Resources
-
-    The primary function of the California Data Exchange Center (CDEC) is to
-    facilitate the collection, storage, and exchange of hydrologic and climate
-    information to support real-time flood management and water supply needs in
-    California.
-
-    California Department of Water Resources: http://www.water.ca.gov/
-    California Data Exchange Center: http://cdec.water.ca.gov
-
-    Downloads data for a set of CDEC station and sensor ids. If either is not
-    provided, all available data will be downloaded.
-
-    Parameters
-    ----------
-    station_id: str
-        [optional, default is None]
-
-        Each string is the CDEC station ID and consist of three capital
-        letters.
-
-    sensor_num: integer, comma separated integers or ``None``
-        [optional, default is None]
-
-        If ``None`` will get all sensors at `station_id`.
-
-        SELECTED CDEC SENSOR NUMBERS (these are not available for all
-        sites):
-
-        +------------+-------------------------------------------+
-        | sensor_num | Description                               |
-        +============+===========================================+
-        | 1          | river stage [ft]                          |
-        +------------+-------------------------------------------+
-        | 2          | precipitation accumulated [in]            |
-        +------------+-------------------------------------------+
-        | 3          | SWE [in]                                  |
-        +------------+-------------------------------------------+
-        | 4          | air temperature [F]                       |
-        +------------+-------------------------------------------+
-        | 5          | EC [ms/cm]                                |
-        +------------+-------------------------------------------+
-        | 6          | reservoir elevation [ft]                  |
-        +------------+-------------------------------------------+
-        | 7          | reservoir scheduled release [cfs]         |
-        +------------+-------------------------------------------+
-        | 8          | full natural flow [cfs]                   |
-        +------------+-------------------------------------------+
-        | 15         | reservoir storage [af]                    |
-        +------------+-------------------------------------------+
-        | 20         | flow -- river discharge [cfs]             |
-        +------------+-------------------------------------------+
-        | 22         | reservoir storage change [af]             |
-        +------------+-------------------------------------------+
-        | 23         | reservoir outflow [cfs]                   |
-        +------------+-------------------------------------------+
-        | 24         | Evapotranspiration [in]                   |
-        +------------+-------------------------------------------+
-        | 25         | water temperature [F]                     |
-        +------------+-------------------------------------------+
-        | 27         | water turbidity [ntu]                     |
-        +------------+-------------------------------------------+
-        | 28         | chlorophyll [ug/l]                        |
-        +------------+-------------------------------------------+
-        | 41         | flow -- mean daily [cfs]                  |
-        +------------+-------------------------------------------+
-        | 45         | precipitation incremental [in]            |
-        +------------+-------------------------------------------+
-        | 46         | runoff volume [af]                        |
-        +------------+-------------------------------------------+
-        | 61         | water dissolved oxygen [mg/l]             |
-        +------------+-------------------------------------------+
-        | 62         | water pH value [pH]                       |
-        +------------+-------------------------------------------+
-        | 64         | pan evaporation (incremental) [in]        |
-        +------------+-------------------------------------------+
-        | 65         | full natural flow [af]                    |
-        +------------+-------------------------------------------+
-        | 66         | flow -- monthly volume [af]               |
-        +------------+-------------------------------------------+
-        | 67         | accretions (estimated) [af]               |
-        +------------+-------------------------------------------+
-        | 71         | spillway discharge [cfs]                  |
-        +------------+-------------------------------------------+
-        | 74         | lake evaporation (computed) [cfs]         |
-        +------------+-------------------------------------------+
-        | 76         | reservoir inflow [cfs]                    |
-        +------------+-------------------------------------------+
-        | 85         | control regulating discharge [cfs]        |
-        +------------+-------------------------------------------+
-        | 94         | top conservation storage (reservoir) [af] |
-        +------------+-------------------------------------------+
-        | 100        | water EC [us/cm]                          |
-        +------------+-------------------------------------------+
-
-    dur_code: str, comma separated strings, or ``None``
-        [optional, default is None]
-
-        Possible values are 'E', 'H', 'D', and 'M' but not
-        all of these time resolutions are available at every station.
-
-        +----------+-------------+
-        | dur_code | Description |
-        +==========+=============+
-        | E        | event       |
-        +----------+-------------+
-        | H        | hourly      |
-        +----------+-------------+
-        | D        | daily       |
-        +----------+-------------+
-        | M        | monthly     |
-        +----------+-------------+
-
-    ${start_date}
-
-    ${end_date}
-
-    """
-    tsutils.printiso(
-        cdec(
-            station_id,
-            dur_code=dur_code,
-            sensor_num=sensor_num,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
 DEFAULT_START_DATE = "01/01/1901"
-DEFAULT_END_DATE = "Now"
 
 
 def get_stations():
-    """Fetch information on all CDEC sites.
+    """
+    Fetch information on all CDEC sites.
 
     Returns
     -------
@@ -226,12 +89,16 @@ def get_stations():
     """
     # I haven't found a better list of stations, seems pretty janky
     # to just have them in a file, and not sure if/when it is updated.
-    url = "https://cdec.water.ca.gov/misc/all_stations.csv"
-    # the csv is malformed, so some rows think there are 7 fields
-    col_names = ["id", "meta_url", "name", "num", "lat", "lon", "junk"]
-    df = pd.read_csv(url, names=col_names, header=None, quotechar="'", index_col=0)
-
-    return df
+    url = "http://cdec.water.ca.gov/misc/all_stations.csv"
+    # the csv is malformed, so some rows think there are 7-8 fields
+    return pd.read_csv(
+        url,
+        names=["id", "meta_url"],
+        usecols=[0, 1],
+        header=None,
+        quotechar="'",
+        index_col=0,
+    )
 
 
 def get_sensors(sensor_id=None):
@@ -242,15 +109,15 @@ def get_sensors(sensor_id=None):
 
     Parameters
     ----------
-    sites : iterable of integers or ``None``
+    sensor_id : iterable of integers or ``None``
 
     Returns
     -------
     df : pandas DataFrame
         a python dict with site codes mapped to site information
-
     """
-    url = "https://cdec.water.ca.gov/misc/senslist.html"
+
+    url = "http://cdec.water.ca.gov/misc/senslist.html"
     df = pd.read_html(url, header=0)[0]
     df.set_index("Sensor No")
 
@@ -298,32 +165,35 @@ def get_station_sensors(station_ids=None, sensor_ids=None, resolutions=None):
         station_ids = get_stations().index
 
     for station_id in station_ids:
-        url = "https://cdec.water.ca.gov/dynamicapp/staMeta?station_id={}".format(
-            station_id
-        )
-        sensor_list = pd.read_html(url)
-        sensor_list = sensor_list[1]
-        sensor_list.columns = [
-            "sensor_description",
-            "sensor_number",
-            "duration",
-            "plot",
-            "data_collection",
-            "data_available",
-        ]
-        v = list(sensor_list["sensor_description"].to_dict().values())
+        url = f"http://cdec.water.ca.gov/dynamicapp/staMeta?station_id={station_id}"
+
+        try:
+            sensor_list = pd.read_html(url, match="Sensor Description")[0]
+        except ValueError:
+            sensor_list = pd.read_html(url)[0]
+
+        try:
+            sensor_list.columns = ["sensor_id", "variable", "resolution", "timerange"]
+        except ValueError:
+            sensor_list.columns = [
+                "variable",
+                "sensor_id",
+                "resolution",
+                "varcode",
+                "method",
+                "timerange",
+            ]
+
+        v = list(sensor_list["variable"].to_dict().values())
         split = [i.split(",") for i in v]
-        var_names = ["_".join(x[:-1]).strip() for x in split]
+        var_names = [" ".join([i.strip() for i in x][:-1]).strip() for x in split]
+        var_names = [i.replace(" ", "_") for i in var_names]
         units = [x[-1][1:] for x in split]
         units = [unit_conv.get(i, i) for i in units]
         var_names = [":".join([i, j]) for i, j in zip(var_names, units)]
-        var_resolution = [x[1:-1] for x in sensor_list["duration"]]
-
+        var_resolution = [x[1:-1] for x in sensor_list["resolution"]]
         sensor_list["resolution"] = var_resolution
-        sensor_list[
-            "variable"
-        ] = var_names  # [x + y for x, y in zip(var_names, var_resolution)]
-
+        sensor_list["variable"] = var_names
         station_sensors[station_id] = _limit_sensor_list(
             sensor_list, sensor_ids, resolutions
         )
@@ -364,7 +234,11 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
     else:
         start_date = pd.Timestamp(start).date()
     if end is None:
-        end_date = pd.Timestamp(DEFAULT_END_DATE).date()
+        end_date = (
+            pd.to_datetime(datetime.datetime.utcnow())
+            .tz_localize("UTC")
+            .tz_convert("America/Los_Angeles")
+        )
     else:
         end_date = pd.Timestamp(end).date()
 
@@ -384,26 +258,16 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
         for _, row in sensor_list.iterrows():
             res = row["resolution"]
             var = row["variable"]
-            sensor_id = row["sensor_number"]
+            sensor_id = row["sensor_id"]
 
-            url = (
-                "https://cdec.water.ca.gov/dynamicapp/req/CSVDataServlet"
-                + "?Stations="
-                + station_id
-                + "&dur_code="
-                + dur_code_map[res]
-                + "&SensorNums="
-                + str(sensor_id)
-                + "&Start="
-                + start_date_str
-                + "&End="
-                + end_date_str
-            )
+            url = f"http://cdec.water.ca.gov/dynamicapp/req/CSVDataServlet?Stations={station_id}&dur_code={dur_code_map[res]}&SensorNums={sensor_id}&Start={start_date_str}&End={end_date_str}"
+            if Path("debug_tsgettoolbox").exists():
+                print(url)
             station_data[var] = pd.read_csv(
                 url,
                 parse_dates=["DATE TIME"],
                 index_col="DATE TIME",
-                na_values="m",
+                na_values=["m", "---"],
             )["VALUE"]
             station_data[var].columns = ["datetime", "value"]
 
@@ -413,8 +277,10 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
 
 
 def _limit_sensor_list(sensor_list, sensor_ids, resolution):
+    """Limit the sensor list to the provided sensor ids and resolutions."""
     if sensor_ids is not None:
-        sensor_list = sensor_list[sensor_list["sensor_number"].isin(sensor_ids)]
+        sensor_list = sensor_list[[x in sensor_ids for x in sensor_list.sensor_id]]
+
     if resolution is not None:
         ncode = [fname_code_map[i] for i in resolution]
         sensor_list = sensor_list[sensor_list["resolution"].isin(ncode)]
@@ -426,15 +292,15 @@ def _limit_sensor_list(sensor_list, sensor_ids, resolution):
 
 
 def download_data(
-    station_id, sensor_num=None, dur_code=None, start_date=None, end_date=None
+    station_id, sensor_nums=None, dur_code=None, start_date=None, end_date=None
 ):
-
-    if isinstance(sensor_num, (str, bytes)):
-        sensor_num = [
-            int(sensor_num_map.get(i.lower(), i)) for i in sensor_num.split(".")
+    """Download data for a single CDEC station and sensor id."""
+    if isinstance(sensor_nums, (str, bytes)):
+        sensor_nums = [
+            int(sensor_num_map.get(i.lower(), i)) for i in sensor_nums.split(".")
         ]
-    elif isinstance(sensor_num, int):
-        sensor_num = [sensor_num]
+    elif isinstance(sensor_nums, int):
+        sensor_nums = [sensor_nums]
 
     if isinstance(dur_code, (str, bytes)):
         dur_code = dur_code.split(",")
@@ -443,46 +309,167 @@ def download_data(
 
     d = get_data(
         [station_id],
-        sensor_ids=tsutils.make_list(sensor_num),
+        sensor_ids=tsutils.make_list(sensor_nums),
         resolutions=tsutils.make_list(dur_code),
         start=start_date,
         end=end_date,
     )
 
     nd = pd.DataFrame()
-    for key in d[station_id]:
-        nnd = pd.DataFrame(d[station_id][key])
+    for key, value in d[station_id].items():
+        nnd = pd.DataFrame(value)
         nnd.columns = [key]
         nd = nd.join(nnd, how="outer")
     nd.rename(
-        lambda x: x.replace(",", "_").replace(" ", "_").replace("__", "_"),
+        lambda x: x.replace(",", "_")
+        .replace(" ", "_")
+        .replace("__", "_")
+        .replace("DEG_F", "degF"),
         axis="columns",
         inplace=True,
     )
-    nd = nd.tz_localize("UTC").tz_convert("Etc/GMT+8")
+    nd = nd.tz_localize("Etc/GMT+8")
+
+    nd = nd.astype("float64")
+    nd = nd.convert_dtypes()
+
     nd.index.name = "Datetime:PST"
     return nd
 
 
+@tsutils.doc(tsutils.docstrings)
 def cdec(
     station_id: str,
     dur_code: Optional[Union[list, str]] = None,
-    sensor_num=None,
+    sensor_nums=None,
     start_date=None,
     end_date=None,
 ):
-    r"""Access data from the `California Department of Water Resources`_."""
-    df = download_data(
+    """US/CA:station::E,H,D,M:California Department of Water Resources
+
+    The primary function of the California Data Exchange Center (CDEC) is to
+    facilitate the collection, storage, and exchange of hydrologic and climate
+    information to support real-time flood management and water supply needs in
+    California.
+
+    California Department of Water Resources: http://www.water.ca.gov/
+    California Data Exchange Center: http://cdec.water.ca.gov
+
+    Downloads data for a set of CDEC station and sensor ids. If either is not
+    provided, all available data will be downloaded.
+
+    Parameters
+    ----------
+    station_id : str
+        [optional, default is None]
+
+        Each string is the CDEC station ID and consist of three capital
+        letters.
+
+    sensor_nums : int, str, list of int or str, or ``None``
+        [optional, default is None]
+
+        If ``None`` will get all sensors at `station_id`.
+
+        SELECTED CDEC SENSOR NUMBERS (these are not available for all
+        sites):
+
+        +-------------+-------------------------------------------+
+        | sensor_nums | Description                               |
+        +=============+===========================================+
+        | 1           | river stage [ft]                          |
+        +-------------+-------------------------------------------+
+        | 2           | precipitation accumulated [in]            |
+        +-------------+-------------------------------------------+
+        | 3           | SWE [in]                                  |
+        +-------------+-------------------------------------------+
+        | 4           | air temperature [F]                       |
+        +-------------+-------------------------------------------+
+        | 5           | EC [ms/cm]                                |
+        +-------------+-------------------------------------------+
+        | 6           | reservoir elevation [ft]                  |
+        +-------------+-------------------------------------------+
+        | 7           | reservoir scheduled release [cfs]         |
+        +-------------+-------------------------------------------+
+        | 8           | full natural flow [cfs]                   |
+        +-------------+-------------------------------------------+
+        | 15          | reservoir storage [af]                    |
+        +-------------+-------------------------------------------+
+        | 20          | flow -- river discharge [cfs]             |
+        +-------------+-------------------------------------------+
+        | 22          | reservoir storage change [af]             |
+        +-------------+-------------------------------------------+
+        | 23          | reservoir outflow [cfs]                   |
+        +-------------+-------------------------------------------+
+        | 24          | Evapotranspiration [in]                   |
+        +-------------+-------------------------------------------+
+        | 25          | water temperature [F]                     |
+        +-------------+-------------------------------------------+
+        | 27          | water turbidity [ntu]                     |
+        +-------------+-------------------------------------------+
+        | 28          | chlorophyll [ug/l]                        |
+        +-------------+-------------------------------------------+
+        | 41          | flow -- mean daily [cfs]                  |
+        +-------------+-------------------------------------------+
+        | 45          | precipitation incremental [in]            |
+        +-------------+-------------------------------------------+
+        | 46          | runoff volume [af]                        |
+        +-------------+-------------------------------------------+
+        | 61          | water dissolved oxygen [mg/l]             |
+        +-------------+-------------------------------------------+
+        | 62          | water pH value [pH]                       |
+        +-------------+-------------------------------------------+
+        | 64          | pan evaporation (incremental) [in]        |
+        +-------------+-------------------------------------------+
+        | 65          | full natural flow [af]                    |
+        +-------------+-------------------------------------------+
+        | 66          | flow -- monthly volume [af]               |
+        +-------------+-------------------------------------------+
+        | 67          | accretions (estimated) [af]               |
+        +-------------+-------------------------------------------+
+        | 71          | spillway discharge [cfs]                  |
+        +-------------+-------------------------------------------+
+        | 74          | lake evaporation (computed) [cfs]         |
+        +-------------+-------------------------------------------+
+        | 76          | reservoir inflow [cfs]                    |
+        +-------------+-------------------------------------------+
+        | 85          | control regulating discharge [cfs]        |
+        +-------------+-------------------------------------------+
+        | 94          | top conservation storage (reservoir) [af] |
+        +-------------+-------------------------------------------+
+        | 100         | water EC [us/cm]                          |
+        +-------------+-------------------------------------------+
+
+    dur_code : str, comma separated strings, or ``None``
+        [optional, default is None]
+
+        Possible values are 'E', 'H', 'D', and 'M' but not
+        all of these time resolutions are available at every station.
+
+        +----------+-------------+
+        | dur_code | Description |
+        +==========+=============+
+        | E        | event       |
+        +----------+-------------+
+        | H        | hourly      |
+        +----------+-------------+
+        | D        | daily       |
+        +----------+-------------+
+        | M        | monthly     |
+        +----------+-------------+
+
+    ${start_date}
+
+    ${end_date}
+
+    """
+    return download_data(
         station_id,
         dur_code=dur_code,
-        sensor_num=sensor_num,
+        sensor_nums=sensor_nums,
         start_date=tsutils.parsedate(start_date),
         end_date=tsutils.parsedate(end_date),
     )
-    return df
-
-
-cdec.__doc__ = cdec_cli.__doc__
 
 
 if __name__ == "__main__":
@@ -491,7 +478,7 @@ if __name__ == "__main__":
         start_date="2017-01-01",
         end_date="2017-02-02",
         dur_code="daily",
-        sensor_num=45,
+        sensor_nums=45,
     )
 
     print("PAR PRECIPITATION")
@@ -502,7 +489,7 @@ if __name__ == "__main__":
         start_date="2020-01-01",
         end_date="2020-10-02",
         dur_code="H",
-        sensor_num=6,
+        sensor_nums=6,
     )
 
     print("PAR RESERVOIR ELEVATION")
