@@ -1,37 +1,20 @@
-# -*- coding: utf-8 -*-
-r"""
-tsgettoolbox command line/library tools to retrieve time series.
-
-This program is a collection of utilities to download data from various
-web services.
 """
-
-from __future__ import absolute_import, division, print_function
+daymet              NAmerica 1km 1980- D,M:Daymet, daily meteorology by
+                    the Oak Ridge National Laboratory
+"""
 
 import datetime
 import logging
 import os
-from io import StringIO
+import warnings
 from typing import List, Literal, Optional, Union
 
-try:
-    import urllib.parse as urlp
-except ImportError:
-    import urllib as urlp
-
-import warnings
-
-import mando
 import pandas as pd
 import pydaymet
-import typic
 
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
-from tstoolbox import tsutils
+__all__ = ["daymet"]
 
 warnings.filterwarnings("ignore")
 
@@ -48,125 +31,15 @@ _units_map = {
     "priestley_taylor": ":mm",
 }
 
+_time_scale_map = {
+    "daily": (pd.offsets.Day(0), pd.offsets.Day(0)),
+    "monthly": (pd.offsets.MonthBegin(0), pd.offsets.MonthEnd(0)),
+    "annual": (pd.offsets.YearBegin(0), pd.offsets.YearEnd(0)),
+}
 
-@mando.command("daymet", formatter_class=HelpFormatter, doctype="numpy")
+
+@tsutils.transform_args(measuredParams=tsutils.make_list, years=tsutils.make_list)
 @tsutils.doc(tsutils.docstrings)
-def daymet_cli(
-    lat,
-    lon,
-    start_date=pd.Timestamp("1980-01-01"),
-    end_date=None,
-    years=None,
-    measuredParams="all",
-    time_scale="daily",
-    snow=False,
-    pet_soil_heat=0.0,
-    pet_alpha=1.26,
-):
-    r"""NAmerica 1km 1980- D,M:Daymet, daily meteorology by the Oak Ridge National Laboratory
-
-    Detailed documentation is at http://daymet.ornl.gov/.  Since this is
-    daily data, it covers midnight to midnight based on local time.
-
-    Parameters
-    ----------
-    lat : float
-        Latitude (required): Enter single geographic point by latitude, value
-        between 52.0N and 14.5N.::
-
-            Example: --lat=43.1
-
-    lon : float
-        Longitude (required): Enter single geographic point by longitude, value
-        between -131.0W and -53.0W.::
-
-            Example: --lon=-85.3
-
-    ${start_date}
-        For North America and Hawaii, the earliest date is 1980-01-01. For
-        Puerto Rico, the earliest date it 1950-01-01.
-
-    ${end_date}
-        The latest end date is usually 12-31 of the previous calendar year,
-        though this is dependent on time required to process that data.
-
-    years : CommaSeparatedYears (optional):
-        Current Daymet product is available from 1980 to the latest
-        full calendar year.::
-
-            Example: --years=2012,2014
-
-        This overrides the start_date and end_date options.
-    measuredParams:
-        [optional, defaults to "all"]
-
-        Use the abbreviations from the following table:
-
-        +-------------------+-------------------------+---------+-------------+
-        | measuredParams    | Description             | Unit    | Time Scales |
-        +===================+=========================+=========+=============+
-        | prcp              | precipitation           | mm      | all         |
-        +-------------------+-------------------------+---------+-------------+
-        | swe               | snow-water equivalent   | kg/m2   | all         |
-        +-------------------+-------------------------+---------+-------------+
-        | tmax              | maximum temperature     | degC    | all         |
-        +-------------------+-------------------------+---------+-------------+
-        | tmin              | minimum temperature     | degC    | all         |
-        +-------------------+-------------------------+---------+-------------+
-        | vp                | vapor pressure          | Pa      | all         |
-        +-------------------+-------------------------+---------+-------------+
-        | dayl              | daylength               | seconds | daily       |
-        +-------------------+-------------------------+---------+-------------+
-        | srad              | shortwave radiation     | W/m2    | daily       |
-        +-------------------+-------------------------+---------+-------------+
-        | penman_monteith   | PET by Penman-Montieth  | mm      | daily       |
-        +-------------------+-------------------------+---------+-------------+
-        | hargreaves_samani | PET by Hargreaves-      | mm      | daily       |
-        |                   | Samani                  |         |             |
-        +-------------------+-------------------------+---------+-------------+
-        | priestley_taylor  | PET by Priestley-Taylor | mm      | daily       |
-        +-------------------+-------------------------+---------+-------------+
-
-        Example: --measuredParams=tmax,tmin
-
-        All variables are returned by default.
-    time_scale:
-        [optional, default is "daily"]
-
-        One of "daily", "monthly", or "annual".
-    snow: bool
-        [optional, defaults to False]
-
-        Separate snowfall from precipitation using Martinez and Gupta (2010)
-        method.
-    pet_soil_heat: float
-        [optional, defaults to 0.0]
-
-        Used in the "penman_monteith" and "priestley_taylor" calculations.
-    pet_alpha: float
-        [optional, defaults to 1.26]
-
-        Used in the "priestley_taylor" calculation where the default 1.26 is
-        for humid regions and 1.74 for arid.
-    """
-    tsutils.printiso(
-        daymet(
-            lat,
-            lon,
-            start_date=start_date,
-            end_date=end_date,
-            years=years,
-            measuredParams=measuredParams,
-            time_scale=time_scale,
-            snow=snow,
-            pet_soil_heat=pet_soil_heat,
-            pet_alpha=pet_alpha,
-        )
-    )
-
-
-@tsutils.transform_args(measuredParams=tsutils.make_list)
-# @typic.al
 def daymet(
     lat: float,
     lon: float,
@@ -206,10 +79,97 @@ def daymet(
     ] = None,
     time_scale: Literal["daily", "monthly", "annual"] = "daily",
     snow: bool = False,
-    pet_soil_heat=0.0,
-    pet_alpha=1.26,
 ):
-    r"""Download data from Daymet by the Oak Ridge National Laboratory."""
+    r"""NAmerica:1km:1980-:D,M:Daymet, daily meteorology by the Oak Ridge National Laboratory
+
+    Detailed documentation is at http://daymet.ornl.gov/.  Since this is
+    daily data, it covers midnight to midnight based on local time.
+
+    Parameters
+    ----------
+    lat : float
+        Latitude (required): Enter single geographic point by latitude, value
+        between 52.0N and 14.5N.::
+
+            Example: --lat=43.1
+
+    lon : float
+        Longitude (required): Enter single geographic point by longitude, value
+        between -131.0W and -53.0W.::
+
+            Example: --lon=-85.3
+
+    ${start_date}
+        For North America and Hawaii, the earliest date is 1980-01-01. For
+        Puerto Rico, the earliest date it 1950-01-01.
+
+    ${end_date}
+        The latest end date is usually 12-31 of the previous calendar year,
+        though this is dependent on time required to process that data.
+
+    years : CommaSeparatedYears (optional):
+        Current Daymet product is available from 1980 to the latest
+        full calendar year.::
+
+            Example: --years=2012,2014
+
+        This overrides the start_date and end_date options.
+
+    measuredParams:
+        [optional, defaults to "all"]
+
+        Use the abbreviations from the following table:
+
+        +-------------------+-------------------------+---------+-------------+
+        | measuredParams    | Description             | Unit    | time_scale  |
+        +===================+=========================+=========+=============+
+        | prcp              | precipitation           | mm      | daily       |
+        |                   |                         |         | monthly     |
+        |                   |                         |         | annual      |
+        +-------------------+-------------------------+---------+-------------+
+        | swe               | snow-water equivalent   | kg/m2   | daily       |
+        |                   |                         |         | monthly     |
+        |                   |                         |         | annual      |
+        +-------------------+-------------------------+---------+-------------+
+        | tmax              | maximum temperature     | degC    | daily       |
+        |                   |                         |         | monthly     |
+        |                   |                         |         | annual      |
+        +-------------------+-------------------------+---------+-------------+
+        | tmin              | minimum temperature     | degC    | daily       |
+        |                   |                         |         | monthly     |
+        |                   |                         |         | annual      |
+        +-------------------+-------------------------+---------+-------------+
+        | vp                | vapor pressure          | Pa      | daily       |
+        |                   |                         |         | monthly     |
+        |                   |                         |         | annual      |
+        +-------------------+-------------------------+---------+-------------+
+        | dayl              | daylength               | seconds | daily       |
+        +-------------------+-------------------------+---------+-------------+
+        | srad              | shortwave radiation     | W/m2    | daily       |
+        +-------------------+-------------------------+---------+-------------+
+        | penman_monteith   | PET by Penman-Montieth  | mm      | daily       |
+        +-------------------+-------------------------+---------+-------------+
+        | hargreaves_samani | PET by Hargreaves-      | mm      | daily       |
+        |                   | Samani                  |         |             |
+        +-------------------+-------------------------+---------+-------------+
+        | priestley_taylor  | PET by Priestley-Taylor | mm      | daily       |
+        +-------------------+-------------------------+---------+-------------+
+
+        Example: --measuredParams=tmax,tmin
+
+        All variables are returned by default.
+
+    time_scale:
+        [optional, default is "daily"]
+
+        One of "daily", "monthly", or "annual".
+
+    snow : bool
+        [optional, defaults to False]
+
+        Separate snowfall from precipitation using Martinez and Gupta (2010)
+        method.
+    """
     years = tsutils.make_list(years)
     avail_params = [
         "tmax",
@@ -230,31 +190,31 @@ def daymet(
         "priestley_taylor",
     ]
 
-    if measuredParams is None or measuredParams == "all":
+    if measuredParams is None or "all" in measuredParams:
         measuredParams = avail_params
     else:
         for testparams in measuredParams:
             if testparams not in avail_params:
                 raise ValueError(
                     tsutils.error_wrapper(
+                        f"""
+                        The measuredParams should be a single string or a list
+                        of strings from {avail_params} You supplied
+                        {testparams}.
                         """
-The measuredParams should be a single string or a list of strings from
-{1}
-You supplied {0}.
-""".format(
-                            testparams, avail_params
-                        )
                     )
                 )
 
-    if time_scale in ["monthly", "annual"]:
+    if time_scale in ("monthly", "annual"):
         for rem in ["srad", "dayl"] + pet_types:
             if rem in measuredParams:
                 measuredParams.remove(rem)
                 logging.warning(
                     tsutils.error_wrapper(
                         f"""
-The parameter {rem} is not available for {time_scale} data."""
+                        The parameter {rem} is not available for {time_scale}
+                        data.
+                        """
                     )
                 )
 
@@ -263,8 +223,15 @@ The parameter {rem} is not available for {time_scale} data."""
         dates = years
     else:
         if end_date is None:
-            end_date = pd.Timestamp(f"{datetime.datetime.now().year - 1}-12-31")
-        dates = (pd.Timestamp(start_date), pd.Timestamp(end_date))
+            end_date = pd.Timestamp(
+                f"{datetime.datetime.now().year - 1}-12-31"
+            ).strftime("%Y-%m-%d")
+        time_code = _time_scale_map[time_scale]
+
+        dates = (
+            (pd.Timestamp(start_date) + time_code[0]).strftime("%Y-%m-%d"),
+            (pd.Timestamp(end_date) + time_code[1]).strftime("%Y-%m-%d"),
+        )
 
     obs_data = [i for i in measuredParams if i not in pet_types]
 
@@ -276,6 +243,7 @@ The parameter {rem} is not available for {time_scale} data."""
             variables=obs_data,
             crs="epsg:4326",
             time_scale=time_scale,
+            snow=snow,
         )
         ndf = ndf.rename(lambda x: x.split()[0], axis="columns")
         ndf = ndf[obs_data]
@@ -289,6 +257,7 @@ The parameter {rem} is not available for {time_scale} data."""
                 crs="epsg:4326",
                 time_scale=time_scale,
                 pet=pet,
+                snow=snow,
             )
             df = df.rename(lambda x: x.split()[0], axis="columns")
             df = df.drop("tmax", axis="columns")
@@ -309,9 +278,6 @@ The parameter {rem} is not available for {time_scale} data."""
     return ndf
 
 
-daymet.__doc__ = daymet_cli.__doc__
-
-
 if __name__ == "__main__":
     r = daymet(
         measuredParams="tmax,tmin",
@@ -320,7 +286,8 @@ if __name__ == "__main__":
         years=[2000, 2001],
     )
 
-    print("Daymet")
+    print("Daymet 1")
+    print("years=[2000, 2001]")
     print(r)
 
     r = daymet(
@@ -331,26 +298,30 @@ if __name__ == "__main__":
         end_date="2000-01-02",
     )
 
-    print("Daymet")
+    print("Daymet 2")
+    print("start_date='1995-04-01', end_date='2000-01-02'")
     print(r)
 
     r = daymet(
         lat=43.1,
         lon=-85.2,
+        end_date="2002-12-31",
     )
 
-    print("Daymet")
+    print("Daymet 3")
+    print("end_date='2002-12-31'")
     print(r)
 
     r = daymet(
         lat=43.1,
         lon=-85.2,
-        start_date="1980",
-        end_date="1981",
+        start_date="1991",
+        end_date="1995",
         time_scale="annual",
     )
 
-    print("Daymet")
+    print("Daymet 4")
+    print("start_date='1991', end_date='1995', time_scale='annual'")
     print(r)
 
     r = daymet(
@@ -361,17 +332,19 @@ if __name__ == "__main__":
         time_scale="monthly",
     )
 
-    print("Daymet")
+    print("Daymet 5")
+    print("start_date='1980', end_date='1981', time_scale='monthly'")
     print(r)
 
     r = daymet(
         lat=43.1,
         lon=-85.2,
-        start_date="2000-04",
+        start_date="2010-04",
         time_scale="annual",
     )
 
-    print("Daymet")
+    print("Daymet 6")
+    print("start_date='2010-04', time_scale='annual'")
     print(r)
 
     r = daymet(
@@ -381,7 +354,8 @@ if __name__ == "__main__":
         time_scale="monthly",
     )
 
-    print("Daymet")
+    print("Daymet 7")
+    print("start_date='2000-04', time_scale='monthly'")
     print(r)
 
     r = daymet(
@@ -390,5 +364,6 @@ if __name__ == "__main__":
         measuredParams="penman_monteith",
     )
 
-    print("Daymet")
+    print("Daymet 8")
+    print("measuredParams='penman_monteith'")
     print(r)
