@@ -1,18 +1,17 @@
-# -*- coding: utf-8 -*-
-"""Download data from Florida Automated Weather Network (FAWN)."""
+"""
+fawn                US/FL 15T,H,D,M:Florida Automated Weather Network
+                    (FAWN)
+"""
 
 import datetime
-
-import mando
-import pandas as pd
-
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
+from contextlib import suppress
 
 import mechanize
-from tstoolbox import tsutils
+import pandas as pd
+
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
+
+__all__ = ["fawn"]
 
 #  "referrer": "https://fawn.ifas.ufl.edu/data/reports/?res",
 #  "referrerPolicy": "no-referrer-when-downgrade",
@@ -119,10 +118,10 @@ locs__ = {
 }
 
 rev_locs = {}
-for key in locs__:
+for key, value in locs__.items():
     rev_locs[key] = key
     rev_locs[str(key)] = key
-    for i in locs__[key]:
+    for i in value:
         rev_locs[i.lower()] = key
 
 # variable names for stations are "loc__XXX" where XXX is one of the keys
@@ -147,9 +146,9 @@ vars__ = {
 }
 
 rev_vars = {}
-for key in vars__:
+for key, value in vars__.items():
     rev_vars[key] = key
-    for i in vars__[key]:
+    for i in value:
         rev_vars[i] = key
 
 # new_units_table = [
@@ -169,16 +168,58 @@ for key in vars__:
 # units_table = "\n".join(["        {0}".format(i) for i in units_table.split("\n")])
 
 
-@mando.command("fawn", formatter_class=HelpFormatter, doctype="numpy")
+def core(data):
+    """Download a chunk of data."""
+    br = mechanize.Browser()
+    br.open("https://fawn.ifas.ufl.edu/data/reports/")
+    br.select_form(nr=0)
+    for key in data:
+        if "locs__" in key or "vars__" in key:
+            br.form.toggle_single(type="checkbox", name=key)
+    br.form["presetRange"] = ["dates"]
+    br.form["fromDate_y"] = [str(data["fromDate_y"])]
+    br.form["fromDate_m"] = [str(data["fromDate_m"])]
+    br.form["fromDate_d"] = [str(data["fromDate_d"])]
+    br.form["toDate_y"] = [str(data["toDate_y"])]
+    br.form["toDate_m"] = [str(data["toDate_m"])]
+    br.form["toDate_d"] = [str(data["toDate_d"])]
+    br.form["reportType"] = [data["reportType"]]
+    response = br.submit(nr=1)
+
+    for line in response.readlines():
+        if b"Cancelled CSV output due to lack of data" in line:
+            return pd.DataFrame()
+
+    response.seek(0)
+    mapparsestr = {
+        "daily": "%d %b %Y",
+        "monthly": "%b %Y",
+        "hourly": "%d %b %Y %I:%M %p",
+        "all": "%b %d %Y %I:%M %p",
+    }
+    df = pd.read_csv(response, parse_dates=True)
+    try:
+        df["Period"] = pd.to_datetime(
+            df["Period"], format=mapparsestr[data["reportType"]]
+        )
+    except KeyError:
+        df["Period"] = pd.to_datetime(
+            df["Observation Time"], format=mapparsestr[data["reportType"]]
+        )
+        df = df.drop(columns=["Observation Time"])
+    df = df.set_index(["FAWN Station", "Period"])
+    return df
+
+
 @tsutils.doc(tsutils.docstrings)
-def fawn_cli(
+def fawn(
     stations,
     variables,
     reportType,
     start_date=datetime.datetime(1998, 1, 1),
     end_date=datetime.datetime.now(),
 ):
-    r"""US/FL 15T,H,D,M:Florida Automated Weather Network (FAWN)
+    r"""US/FL:station::15T,H,D,M:Florida Automated Weather Network (FAWN)
 
     Parameters
     ----------
@@ -232,6 +273,7 @@ def fawn_cli(
         * 435  'St. Lucie West'
         * 302  Umatilla
         * 425  Wellington
+
     variables : str
         At the command line can supply a comma separated list of variable
         names.  Using the Python API needs to be a Python list.
@@ -270,105 +312,58 @@ def fawn_cli(
 
         The 'ET' variable is only available when `reportType` is "daily" or
         "monthly".
+
     reportType : str
         Interval of the data.  Can be one of "all" for 15 minute, "hourly",
         "daily", or "monthly".
+
     ${start_date}
+
     ${end_date}
     """
-    tsutils.printiso(
-        fawn(
-            stations,
-            variables,
-            reportType,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
-def core(data):
-    """Download a chunk of data."""
-    br = mechanize.Browser()
-    br.open("https://fawn.ifas.ufl.edu/data/reports/")
-    br.select_form(nr=0)
-    for key in data:
-        if "locs__" in key or "vars__" in key:
-            br.form.toggle_single(type="checkbox", name=key)
-    br.form["presetRange"] = ["dates"]
-    br.form["fromDate_y"] = [str(data["fromDate_y"])]
-    br.form["fromDate_m"] = [str(data["fromDate_m"])]
-    br.form["fromDate_d"] = [str(data["fromDate_d"])]
-    br.form["toDate_y"] = [str(data["toDate_y"])]
-    br.form["toDate_m"] = [str(data["toDate_m"])]
-    br.form["toDate_d"] = [str(data["toDate_d"])]
-    br.form["reportType"] = [data["reportType"]]
-    response = br.submit(nr=1)
-
-    for line in response.readlines():
-        if b"Cancelled CSV output due to lack of data" in line:
-            return pd.DataFrame()
-
-    response.seek(0)
-    df = pd.read_csv(response, index_col=[0, 1], parse_dates=True)
-    return df
-
-
-# @tsutils.validator(
-#    stations=[
-#        [str.lower, ["domain", list(rev_locs.keys())], None],
-#        [int, ["domain", list(locs__.keys())], None],
-#    ],
-#    variables=[str, ["domain", list(vars__.keys()) + list(rev_vars.keys())], None],
-#    reportType=[str, ["domain", ["all", "hourly", "daily", "monthly", "entire"]], 1],
-#    start_date=[tsutils.parsedate, ["pass", []], 1],
-#    end_date=[tsutils.parsedate, ["pass", []], 1],
-# )
-def fawn(
-    stations,
-    variables,
-    reportType,
-    start_date=datetime.datetime(1998, 1, 1),
-    end_date=datetime.datetime.now(),
-):
-    r"""Download data from FAWN."""
     interval = {"all": 10, "hourly": 40, "daily": 366, "monthly": 8000}
-    data = {}
-    data["start_date"] = tsutils.parsedate(start_date)
-    data["end_date"] = tsutils.parsedate(end_date)
+    data = {
+        "start_date": tsutils.parsedate(start_date),
+        "end_date": tsutils.parsedate(end_date),
+    }
+
+    if reportType not in reportTypes:
+        raise ValueError(
+            tsutils.error_wrapper(
+                f"""
+            reportType must be one of {reportTypes} but got
+            {reportType}"""
+            )
+        )
 
     data["reportType"] = reportType
 
     for station in tsutils.make_list(stations):
         try:
-            data["locs__{}".format(rev_locs[station])] = "on"
+            data[f"locs__{rev_locs[station]}"] = "on"
         except KeyError:
             try:
-                data["locs__{}".format(rev_locs[station.lower()])] = "on"
+                data[f"locs__{rev_locs[station.lower()]}"] = "on"
             except KeyError:
                 raise ValueError(
                     tsutils.error_wrapper(
+                        f"""
+                        Station {station} is not in the list of stations.
                         """
-Station {station} is not in the list of stations.
-                                 """.format(
-                            **locals()
-                        )
                     )
                 )
 
     for variable in tsutils.make_list(variables):
         try:
-            data["vars__{}".format(rev_vars[variable])] = "on"
-        except KeyError:
+            data[f"vars__{rev_vars[variable]}"] = "on"
+        except KeyError as exc:
             raise ValueError(
                 tsutils.error_wrapper(
+                    f"""
+                    Variable {variable} is not available.
                     """
-Variable {variable} is not available.
-""".format(
-                        **locals()
-                    )
                 )
-            )
+            ) from exc
 
     ndf = pd.DataFrame()
 
@@ -379,7 +374,6 @@ Variable {variable} is not available.
 
     testdate = sdate
     while testdate < edate:
-
         begin_test_date = tsutils.parsedate(testdate)
         data["fromDate_m"] = begin_test_date.month
         data["fromDate_d"] = begin_test_date.day
@@ -401,29 +395,22 @@ Variable {variable} is not available.
             continue
 
         # With multi-index pandas won't combine_first with an empty ndf.
-        if len(ndf) == 0:
-            ndf = df
-        else:
-            ndf = ndf.combine_first(df)
-
+        ndf = df if len(ndf) == 0 else ndf.combine_first(df)
     if len(ndf) == 0:
         raise ValueError(
             tsutils.error_wrapper(
+                f"""
+                FAWN service returned no values for stations "{stations}",
+                variables "{variables}" between "{sdate}" and "{edate}".
                 """
-FAWN service returned no values for stations "{stations}", variables "{variables}"
-between "{sdate}" and "{edate}".
-""".format(
-                    **locals()
-                )
             )
         )
 
-    try:
+    with suppress(KeyError):
         ndf.drop(columns="N (# obs)", inplace=True)
-    except KeyError:
-        pass
 
     def renamer(istr):
+        """Rename columns by replacement."""
         istr = istr.replace(" ", "")
         istr = istr.replace("(", ":")
         istr = istr.replace(")", ":")
@@ -436,14 +423,14 @@ between "{sdate}" and "{edate}".
     ndf.columns = ["_".join(tup).rstrip("_") for tup in ndf.columns.values]
 
     if reportType != "entire":
+        _pd_major, _pd_minor, _ = pd.__version__.split(".")
         mapfreqstr = {"daily": "D", "monthly": "M", "hourly": "H", "all": "15T"}
+        if (int(_pd_major), int(_pd_minor)) >= (2, 1):
+            mapfreqstr = {"daily": "D", "monthly": "M", "hourly": "h", "all": "15min"}
         ndf.index = ndf.index.to_period(mapfreqstr[reportType])
     return ndf
 
 
-fawn.__doc__ = fawn_cli.__doc__
-
-
 if __name__ == "__main__":
     r = fawn(
         stations="260",
