@@ -1,17 +1,12 @@
-# -*- coding: utf-8 -*-
-"""Download data from Florida Automated Weather Network (FAWN)."""
-
-import mando
-import pandas as pd
-
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
-
-from tstoolbox import tsutils
+"""
+metdata             NAmerica 4km 1980- D: Download daily data from METDATA
+                    based on PRISM.
+"""
 
 from tsgettoolbox import utils
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
+
+__all__ = ["metdata"]
 
 _vars = {
     "pr": {
@@ -272,16 +267,15 @@ _vars = {
 tsutils.docstrings.update({k: f"{v['standard_name']:50}" for k, v in _vars.items()})
 
 
-@mando.command("metdata", formatter_class=HelpFormatter, doctype="numpy")
 @tsutils.doc(tsutils.docstrings)
-def metdata_cli(
+def metdata(
     lat,
     lon,
     variables=None,
     start_date=None,
     end_date=None,
 ):
-    r"""NAmerica 4km 1980- D: Download daily data from METDATA based on PRISM.
+    r"""NAmerica:4km:1980-:D:Download daily data from METDATA based on PRISM.
 
     This archive contains daily surface meteorological (METDATA) data for the
     Continental United States at 4-km (1/24-deg) resolution. The meteorological
@@ -395,13 +389,15 @@ def metdata_cli(
     Parameters
     ----------
     ${lat}
+
     ${lon}
+
     variables : str
         At the command line can supply a comma separated list of variable
         names.  Using the Python API needs to be a Python list of strings.
 
-        The current list of available METDATA variables are in the following table and
-        you can use either the "Short" or "Long" names.
+        The current list of available METDATA variables are in the
+        following table and you can use either the "Short" or "Long" names.
 
         +----------+----------------------------------------------------+-------+
         | Short    | Long                                               | Units |
@@ -488,40 +484,22 @@ def metdata_cli(
         +----------+----------------------------------------------------+-------+
 
     ${start_date}
+
     ${end_date}
     """
-    tsutils.printiso(
-        metdata(
-            lat,
-            lon,
-            variables=variables,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
-def metdata(
-    lat,
-    lon,
-    variables=None,
-    start_date=None,
-    end_date=None,
-):
-    r"""Download METDATA data."""
     if variables is None:
-        vars = list(_vars.keys())
-        vars.sort()
+        cvars = sorted(_vars.keys())
     else:
-        vars = tsutils.make_list(variables)
+        cvars = tsutils.make_list(variables)
 
-    turl = "http://thredds.northwestknowledge.net:8080/thredds/dodsC/agg_met_{}_1979_CurrentYear_CONUS.nc"
-    df = utils.opendap(
+    turl = "dap2://thredds.northwestknowledge.net:8080/thredds/dodsC/agg_met_{}_1979_CurrentYear_CONUS.nc"
+    # turl = "http://thredds.northwestknowledge.net:8080/thredds/ncss/grid/agg_met_{}_1979_CurrentYear_CONUS.nc"
+    return utils.opendap(
         turl,
         lat,
         lon,
         _vars,
-        variables=variables,
+        variables=cvars,
         start_date=start_date,
         end_date=end_date,
         tzname=None,
@@ -530,11 +508,6 @@ def metdata(
         single_var_url=True,
     )
 
-    return df
-
-
-metdata.__doc__ = metdata_cli.__doc__
-
 
 if __name__ == "__main__":
     r = metdata(29.6, -82.3, variables="pr")
