@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
-"""Download data from terraclimate."""
+"""
+terraclimate        global 1/24deg 1958- M:Download monthly data from
+                    Terraclimate.
+"""
 
 # http://thredds.northwestknowledge.net:8080/thredds/terraclimate_aggregated.html
 
-import mando
 import pandas as pd
 
 from tsgettoolbox import utils
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
-
-from tstoolbox import tsutils
+__all__ = ["terraclimate"]
 
 _avail_vars = {
     "aet": {
@@ -117,16 +114,16 @@ _avail_vars = {
 }
 
 
-@mando.command("terraclimate", formatter_class=HelpFormatter, doctype="numpy")
+@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
 @tsutils.doc(tsutils.docstrings)
-def terraclimate_cli(
+def terraclimate(
     lat: float,
     lon: float,
     variables=None,
     start_date=None,
     end_date=None,
 ):
-    r"""global 1/24deg 1958- M:Download monthly data from Terraclimate.
+    r"""global:1/24deg:1958-:M:Download monthly data from Terraclimate.
 
     method: These layers from TerraClimate were derived from the essential
     climate variables of TerraClimate. Water balance variables, actual
@@ -255,36 +252,14 @@ def terraclimate_cli(
 
     ${end_date}
     """
-    tsutils.printiso(
-        terraclimate(
-            lat,
-            lon,
-            variables=variables,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
-@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
-def terraclimate(
-    lat: float,
-    lon: float,
-    variables=None,
-    start_date=None,
-    end_date=None,
-):
-    r"""Download terraclimate data."""
     if variables is None:
-        vars = list(_avail_vars.keys())
-        vars.sort()
+        variables = sorted(_avail_vars.keys())
     else:
-        vars = tsutils.make_list(variables)
+        variables = tsutils.make_list(variables)
 
-    # turl = "http://thredds.northwestknowledge.net:8080/thredds/dodsC/agg_terraclimate_{}_1958_CurrentYear_GLOBE.nc"
     turl = "http://www.reacchpna.org/thredds/dodsC/agg_terraclimate_{}_1958_CurrentYear_GLOBE.nc"
-    # turl = f"https://tds-proxy.nkn.uidaho.edu/thredds/dodsC/agg_terraclimate_{var}_1958_CurrentYear_GLOBE.nc"
-    df = utils.opendap(
+    turl = "http://thredds.northwestknowledge.net:8080/thredds/dodsC/agg_terraclimate_{}_1958_CurrentYear_GLOBE.nc"
+    return utils.opendap(
         turl,
         lat,
         lon,
@@ -295,16 +270,11 @@ def terraclimate(
         tzname=None,
         missing_value=None,
         time_name="time",
-        user_charset="utf-8",
         single_var_url=True,
     )
 
-    return df
-
-
-terraclimate.__doc__ = terraclimate_cli.__doc__
-
 
 if __name__ == "__main__":
     r = terraclimate(29.6, -82.3)
+    print(r.columns)
     print(r)
