@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
-"""Download data from terraclimate."""
+"""
+terraclimate19812010
+                    global 1/24deg M:Monthly normals using TerraClimate
+"""
 
 # http://thredds.northwestknowledge.net:8080/thredds/terraclimate_aggregated.html
 
 import datetime
 
-import mando
 import pandas as pd
 
 from tsgettoolbox import utils
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
-
-from tstoolbox import tsutils
+__all__ = ["terraclimate19812010"]
 
 _avail_vars = {
     "aet": {
@@ -99,16 +96,16 @@ _avail_vars = {
 }
 
 
-@mando.command("terraclimate19812010", formatter_class=HelpFormatter, doctype="numpy")
+@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
 @tsutils.doc(tsutils.docstrings)
-def terraclimate19812010_cli(
+def terraclimate19812010(
     lat: float,
     lon: float,
     variables=None,
     start_date=None,
     end_date=None,
 ):
-    r"""global 1/24deg M:Monthly normals using TerraClimate monthly data from 1981 to 2010.
+    r"""global:1/24deg::M:Monthly normals using TerraClimate monthly data from 1981 to 2010.
 
     method: These layers from TerraClimate were derived from the essential
     climate variables of TerraClimate. Water balance variables, actual
@@ -235,26 +232,6 @@ def terraclimate19812010_cli(
 
     ${end_date}
     """
-    tsutils.printiso(
-        terraclimate19812010(
-            lat,
-            lon,
-            variables=variables,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
-@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
-def terraclimate19812010(
-    lat: float,
-    lon: float,
-    variables=None,
-    start_date=None,
-    end_date=None,
-):
-    r"""Download terraclimate data."""
     turl = "http://thredds.northwestknowledge.net:8080/thredds/dodsC/TERRACLIMATE_ALL/summaries/TerraClimate19812010_{}.nc"
 
     df = utils.opendap(
@@ -279,9 +256,6 @@ def terraclimate19812010(
     return df
 
 
-terraclimate19812010.__doc__ = terraclimate19812010_cli.__doc__
-
-
 if __name__ == "__main__":
     r = terraclimate19812010(29.6, -82.3)
     print(r)
