@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
-"""Download data from terraclimate."""
+"""
+terraclimate2C      global 1/24deg M:Monthly normals from Terraclimate
+                    with 2deg C hotter climate.
+"""
 
 # http://thredds.northwestknowledge.net:8080/thredds/terraclimate_aggregated.html
 
-import mando
 import pandas as pd
 
 from tsgettoolbox import utils
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
-
-from tstoolbox import tsutils
+__all__ = ["terraclimate2C"]
 
 _avail_vars = {
     "aet": {
@@ -82,16 +79,16 @@ _avail_vars = {
 }
 
 
-@mando.command("terraclimate2C", formatter_class=HelpFormatter, doctype="numpy")
+@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
 @tsutils.doc(tsutils.docstrings)
-def terraclimate2C_cli(
+def terraclimate2C(
     lat: float,
     lon: float,
     variables=None,
     start_date=None,
     end_date=None,
 ):
-    r"""global 1/24deg M:Monthly normals from Terraclimate with 2deg C hotter climate.
+    r"""global:1/24deg::M:Monthly normals from Terraclimate with 2deg C hotter climate.
 
     method: These layers from TerraClimate were derived from the essential
     climate variables of TerraClimate. Water balance variables, actual
@@ -218,26 +215,6 @@ def terraclimate2C_cli(
 
     ${end_date}
     """
-    tsutils.printiso(
-        terraclimate2C(
-            lat,
-            lon,
-            variables=variables,
-            start_date=start_date,
-            end_date=end_date,
-        )
-    )
-
-
-@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
-def terraclimate2C(
-    lat: float,
-    lon: float,
-    variables=None,
-    start_date=None,
-    end_date=None,
-):
-    r"""Download terraclimate data."""
     turl = "http://thredds.northwestknowledge.net:8080/thredds/dodsC/TERRACLIMATE_ALL/summaries/TerraClimate2C_{}.nc"
 
     df = utils.opendap(
@@ -257,9 +234,6 @@ def terraclimate2C(
     return df
 
 
-terraclimate2C.__doc__ = terraclimate2C_cli.__doc__
-
-
 if __name__ == "__main__":
     r = terraclimate2C(29.6, -82.3)
     print(r)
