@@ -1,39 +1,35 @@
-# -*- coding: utf-8 -*-
+"""
+unavco              US station: Download data from the Unavco web
+                    services.
+"""
+
 import logging
 import os
 from io import BytesIO
 
 import async_retriever as ar
-import mando
 import pandas as pd
 
-try:
-    from mando.rst_text_formatter import RSTHelpFormatter as HelpFormatter
-except ImportError:
-    from argparse import RawTextHelpFormatter as HelpFormatter
+from tsgettoolbox.toolbox_utils.src.toolbox_utils import tsutils
 
-from tstoolbox import tsutils
+__all__ = ["unavco"]
 
 
 def unavco_to_df(url, **query_params):
+    """Get data from unavco and return a dataframe."""
     try:
         station = query_params.pop("station")
-    except KeyError:
+    except KeyError as e:
         raise KeyError(
-            """
+            f"""
 *
 *   The station keyword is required.  You have given me
-*   {}.
+*   {query_params}.
 *
-""".format(
-                query_params
-            )
-        )
-    url = "{}/{}/beta".format(url, station)
-    if "/met/" in url or "/strain/" in url:
-        comment = None
-    else:
-        comment = "#"
+"""
+        ) from e
+    url = f"{url}/{station}/beta"
+    comment = None if "/met/" in url or "/strain/" in url else "#"
     query_params["starttime"] = tsutils.parsedate(query_params["starttime"]).isoformat()
     query_params["endtime"] = tsutils.parsedate(query_params["endtime"]).isoformat()
     query_params["tsFormat"] = "iso8601"
@@ -51,7 +47,7 @@ def unavco_to_df(url, **query_params):
             BytesIO(i),
             header=0,
             index_col=0,
-            parse_dates=[0],
+            parse_dates=True,
             comment=comment,
             skiprows=5,
         )
@@ -59,22 +55,15 @@ def unavco_to_df(url, **query_params):
     ]
     df = pd.concat(resp)
     df.columns = [
-        "unavco-{}".format(
-            i.strip()
-            .replace(" ", "_")
-            .replace("(", ":")
-            .replace(")", "")
-            .replace("deg._C", "degC")
-        )
+        f"unavco-{i.strip().replace(' ', '_').replace('(', ':').replace(')', '').replace('deg._C', 'degC')}"
         for i in df.columns
     ]
     df.index.name = "Datetime:UTC"
     return df
 
 
-@mando.command("unavco", formatter_class=HelpFormatter, doctype="numpy")
-def unavco_cli(station, database="met", starttime=None, endtime=None):
-    r"""US station: Download data from the Unavco web services.
+def unavco(station, database="met", starttime=None, endtime=None):
+    r"""US:station:::Download data from the Unavco web services.
 
     Detailed information at:
     http://www.unavco.com/data/web-services/web-services.html
@@ -167,13 +156,6 @@ def unavco_cli(station, database="met", starttime=None, endtime=None):
     endtime
         End date in ISO8601 format.
     """
-    tsutils.printiso(
-        unavco(station, database=database, starttime=starttime, endtime=endtime)
-    )
-
-
-def unavco(station, database="met", starttime=None, endtime=None):
-    r"""Download data from the Unavco web services."""
     map_db_to_url = {
         "met": r"http://web-services.unavco.org:80/met/data",
         "pore_temperaure": r"http://web-services.unavco.org:80"
@@ -182,13 +164,12 @@ def unavco(station, database="met", starttime=None, endtime=None):
         "tilt": r"http://web-services.unavco.org:80/tilt/data",
         "strain": r"http://web-services.unavco.org:80/strain/data/L2",
     }
-    df = unavco_to_df(
-        map_db_to_url[database], station=station, starttime=starttime, endtime=endtime
+    return unavco_to_df(
+        map_db_to_url[database],
+        station=station,
+        starttime=starttime,
+        endtime=endtime,
     )
-    return df
-
-
-unavco.__doc__ = unavco_cli.__doc__
 
 
 if __name__ == "__main__":
