@@ -1,2 +1,2 @@
-# -*- coding: utf-8 -*-
+__all__ = ["historical"]
 from . import historical
