@@ -1,68 +1,68 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.cdec.historical.core
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~
+ulmo.cdec.historical.core
+~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides access to data provided by the `California Department
-    of Water Resources`_ `California Data Exchange Center`_ web site.
+This module provides access to data provided by the `California Department
+of Water Resources`_ `California Data Exchange Center`_ website.
 
-    .. _California Department of Water Resources: http://www.water.ca.gov/
-    .. _California Data Exchange Center: http://cdec.water.ca.gov
+.. _California Department of Water Resources: http://www.water.ca.gov/
+.. _California Data Exchange Center: http://cdec.water.ca.gov
 
 
-    SELECTED CDEC SENSOR NUMBERS (these are not be available for all sites):
+SELECTED CDEC SENSOR NUMBERS (these are not available for all sites):
 
-    1    river stage [ft]
-    2    precipitation, accumulated [in]
-    3    SWE [in]
-    4    air temperature [F]
-    5    EC [ms/cm]
-    6    reservoir elevation [ft]
-    7    reservoir scheduled release [cfs]
-    8    full natural flow [cfs]
-    15   reservoir storage [af]
-    20   flow -- river discharge [cfs]
-    22   reservoir storage change [af]
-    23   reservoir outflow [cfs]
-    24   Evapotranspiration [in]
-    25   water temperature [F]
-    27   water turbidity [ntu]
-    28   chlorophyll [ug/l]
-    41   flow -- mean daily [cfs]
-    45   precipitation, incremental [in]
-    46   runoff volume [af]
-    61   water dissolved oxygen [mg/l]
-    62   water pH value [pH]
-    64   pan evaporation (incremental) [in]
-    65   full natural flow [af]
-    66   flow -- monthly volume [af]
-    67   accretions (estimated) [af]
-    71   spillway discharge [cfs]
-    74   lake evaporation (computed) [cfs]
-    76   reservoir inflow [cfs]
-    85   control regulating discharge [cfs]
-    94   top conservation storage (reservoir) [af]
-    100  water EC [us/cm]
+1    river stage [ft]
+2    precipitation, accumulated [in]
+3    SWE [in]
+4    air temperature [F]
+5    EC [ms/cm]
+6    reservoir elevation [ft]
+7    reservoir scheduled release [cfs]
+8    full natural flow [cfs]
+15   reservoir storage [af]
+20   flow -- river discharge [cfs]
+22   reservoir storage change [af]
+23   reservoir outflow [cfs]
+24   Evapotranspiration [in]
+25   water temperature [F]
+27   water turbidity [ntu]
+28   chlorophyll [ug/l]
+41   flow -- mean daily [cfs]
+45   precipitation, incremental [in]
+46   runoff volume [af]
+61   water dissolved oxygen [mg/l]
+62   water pH value [pH]
+64   pan evaporation (incremental) [in]
+65   full natural flow [af]
+66   flow -- monthly volume [af]
+67   accretions (estimated) [af]
+71   spillway discharge [cfs]
+74   lake evaporation (computed) [cfs]
+76   reservoir inflow [cfs]
+85   control regulating discharge [cfs]
+94   top conservation storage (reservoir) [af]
+100  water EC [us/cm]
 
-    CDEC DURATION CODES:
+CDEC DURATION CODES:
 
-    E    event
-    H    hourly
-    D    daily
-    M    monthly
+E    event
+H    hourly
+D    daily
+M    monthly
 
 """
 
 import pandas as pd
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 DEFAULT_START_DATE = "01/01/1901"
 DEFAULT_END_DATE = "Now"
 
 
 def get_stations():
-    """Fetches information on all CDEC sites.
+    """
+    Fetches information on all CDEC sites.
 
     Returns
     -------
@@ -72,11 +72,16 @@ def get_stations():
     # I haven't found a better list of stations, seems pretty janky
     # to just have them in a file, and not sure if/when it is updated.
     url = "http://cdec.water.ca.gov/misc/all_stations.csv"
-    # the csv is malformed, so some rows think there are 7 fields
-    col_names = ["id", "meta_url", "name", "num", "lat", "lon", "junk"]
-    df = pd.read_csv(url, names=col_names, header=None, quotechar="'", index_col=0)
-
-    return df
+    # the csv is malformed, so some rows think there are 7-8 fields
+    col_names = ["id", "meta_url", "name", "num", "lat", "lon"]
+    return pd.read_csv(
+        url,
+        names=col_names,
+        header=None,
+        quotechar="'",
+        index_col=0,
+        on_bad_lines="skip",
+    )
 
 
 def get_sensors(sensor_id=None):
@@ -94,20 +99,19 @@ def get_sensors(sensor_id=None):
 
     Parameters
     ----------
-    sites : iterable of integers or ``None``
+    sensor_id : iterable of integers or ``None``
 
     Returns
     -------
     df : pandas DataFrame
         a python dict with site codes mapped to site information
     """
+
     url = "http://cdec.water.ca.gov/misc/senslist.html"
     df = pd.read_html(url, header=0)[0]
     df.set_index("Sensor No")
 
-    if sensor_id is None:
-        return df
-    return df.loc[sensor_id]
+    return df if sensor_id is None else df.loc[sensor_id]
 
 
 def get_station_sensors(station_ids=None, sensor_ids=None, resolutions=None):
@@ -151,16 +155,16 @@ def get_station_sensors(station_ids=None, sensor_ids=None, resolutions=None):
         station_ids = get_stations().index
 
     for station_id in station_ids:
-        url = "http://cdec.water.ca.gov/dynamicapp/staMeta?station_id=%s" % (station_id)
+        url = f"http://cdec.water.ca.gov/dynamicapp/staMeta?station_id={station_id}"
 
         try:
             sensor_list = pd.read_html(url, match="Sensor Description")[0]
-        except:
+        except Exception:
             sensor_list = pd.read_html(url)[0]
 
         try:
             sensor_list.columns = ["sensor_id", "variable", "resolution", "timerange"]
-        except:
+        except Exception:
             sensor_list.columns = [
                 "variable",
                 "sensor_id",
@@ -209,6 +213,7 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
         a python dict with site codes as keys. Values will be nested dicts
         containing all of the sensor/resolution combinations.
     """
+
     if start is None:
         start_date = util.convert_date(DEFAULT_START_DATE)
     else:
@@ -231,7 +236,7 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
     for station_id, sensor_list in list(sensors.items()):
         station_data = {}
 
-        for index, row in sensor_list.iterrows():
+        for _, row in sensor_list.iterrows():
             res = row.loc["resolution"]
             var = row.loc["variable"]
             sensor_id = row.loc["sensor_id"]
@@ -248,7 +253,6 @@ def get_data(station_ids=None, sensor_ids=None, resolutions=None, start=None, en
 
 
 def _limit_sensor_list(sensor_list, sensor_ids, resolution):
-
     if sensor_ids is not None:
         sensor_list = sensor_list[[x in sensor_ids for x in sensor_list.sensor_id]]
 
@@ -259,9 +263,8 @@ def _limit_sensor_list(sensor_list, sensor_ids, resolution):
 
 
 def _download_raw(station_id, sensor_num, dur_code, start_date, end_date):
-
     url = (
-        "http://cdec.water.ca.gov/dynamicapp/req/CSVDataServlet"
+        "https://cdec.water.ca.gov/dynamicapp/req/CSVDataServlet"
         + "?Stations="
         + station_id
         + "&dur_code="
@@ -290,10 +293,10 @@ def _download_raw(station_id, sensor_num, dur_code, start_date, end_date):
 
 
 def _res_to_dur_code(res):
-    map = {"hourly": "H", "daily": "D", "monthly": "M", "event": "E"}
+    code_map = {"hourly": "H", "daily": "D", "monthly": "M", "event": "E"}
 
-    return map[res]
+    return code_map[res]
 
 
 def _format_date(date):
-    return "{}/{}/{}".format(date.month, date.day, date.year)
+    return f"{date.month:02}/{date.day:02}/{date.year}"
