@@ -1,15 +1,13 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.cpc.drought.core
-    ~~~~~~~~~~~~~~~~~~~~~
+ulmo.cpc.drought.core
+~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides direct access to `Climate Predicition Center`_ `Weekly
-    Drought Index`_ dataset.
+This module provides direct access to `Climate Predicition Center`_ `Weekly
+Drought Index`_ dataset.
 
-    .. _Climate Prediction Center: https://www.cpc.ncep.noaa.gov/
-    .. _Weekly Drought Index: https://www.cpc.ncep.noaa.gov/products/analysis_monitoring/cdus/palmer_drought/
+.. _Climate Prediction Center: http://www.cpc.ncep.noaa.gov/
+.. _Weekly Drought Index: http://www.cpc.ncep.noaa.gov/products/analysis_monitoring/cdus/palmer_drought/
 """
-from __future__ import division
 
 import datetime
 import os
@@ -18,7 +16,7 @@ import numpy as np
 import pandas
 import requests
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 # directory where drought data will be stashed
 CPC_DROUGHT_DIR = os.path.join(util.get_ulmo_dir(), "cpc/drought")
@@ -80,19 +78,20 @@ STATE_CODES = {
 def get_data(
     state=None, climate_division=None, start=None, end=None, as_dataframe=False
 ):
-    """Retreives data.
+    """
+    Retrieve data.
 
     Parameters
     ----------
-    state : ``None`` or str
+    state: ``None`` or str
         If specified, results will be limited to the state corresponding to the
         given 2-character state code.
-    climate_division : ``None`` or int
+    climate_division: ``None`` or int
         If specified, results will be limited to the climate division.
-    start : ``None`` or date (see :ref:`dates-and-times`)
+    start: ``None`` or date (see :ref:`dates-and-times`)
         Results will be limited to those after the given date. Default is the
         start of the current calendar year.
-    end : ``None`` or date (see :ref:`dates-and-times`)
+    end: ``None`` or date (see :ref:`dates-and-times`)
         If specified, results will be limited to data before this date.
     as_dataframe: bool
         If ``False`` (default), a dict with a nested set of dicts will be
@@ -107,27 +106,19 @@ def get_data(
         A dict or pandas.DataFrame representing the data. See the
         ``as_dataframe`` parameter for more.
     """
-    if start is not None:
-        start_date = util.convert_date(start)
-    else:
-        start_date = None
-    if end is not None:
-        end_date = util.convert_date(end)
-    else:
-        end_date = None
 
-    if not end_date:
-        end_date = datetime.date.today()
-    if not start_date:
-        start_date = datetime.date(end_date.year, 1, 1)
+    end_date = (
+        None if end is None else util.convert_date(end)
+    ) or datetime.date.today()
 
-    start_year, start_week = _week_number(start_date)
-    end_year, end_week = _week_number(end_date)
-    if state:
-        state_code = STATE_CODES.get(state.upper())
-    else:
-        state_code = None
+    start_date = (None if start is None else util.convert_date(start)) or datetime.date(
+        end_date.year, 1, 1
+    )
 
+    start_year, _ = _week_number(start_date)
+    end_year, _ = _week_number(end_date)
+
+    state_code = STATE_CODES.get(state.upper()) if state else None
     data = None
     for year in range(start_year, end_year + 1):
         url, current_year_flag = _get_data_url(year)
@@ -141,6 +132,7 @@ def get_data(
             year_data = year_data[year_data["state_code"] == state_code]
         if climate_division:
             year_data = year_data[year_data["climate_division"] == climate_division]
+
         year_data = _reindex_data(year_data)
 
         if data is None:
@@ -154,18 +146,16 @@ def get_data(
 
     # restrict results to date range
     period_index = pandas.PeriodIndex(data["period"])
-    periods_in_range = (period_index >= start_date.isoformat()) & (
-        period_index <= end_date.isoformat()
-    )
-    period_index = period_index[periods_in_range]
+    periods_in_range = (period_index >= start_date) & (period_index <= end_date)
     data = data[periods_in_range]
 
     # this does what data.reset_index() should do, but at least as of 0.10.1, that sets
     # will cast period objects to ints
-    data.index = period_index.to_timestamp()  # np.arange(len(data))
-    if as_dataframe:
-        return data
-    return _as_data_dict(data)
+    try:
+        data.index = period_index.to_timestamp()
+    except AttributeError:
+        data.index = np.arange(len(data))
+    return data if as_dataframe else _as_data_dict(data)
 
 
 def _as_data_dict(dataframe):
@@ -174,11 +164,9 @@ def _as_data_dict(dataframe):
         state_dict = {}
         state_dataframe = dataframe[dataframe["state"] == state]
         for name, group in state_dataframe.groupby(["state", "climate_division"]):
-            s, climate_division = name
+            _, climate_division = name
             climate_division_data = group.T.drop(["state", "climate_division"])
-            values = [
-                _value_dict(value) for k, value in climate_division_data.iteritems()
-            ]
+            values = [_value_dict(value) for k, value in climate_division_data.items()]
             state_dict[climate_division] = values
         data_dict[state] = state_dict
     return data_dict
@@ -231,19 +219,16 @@ def _first_sunday(year):
 def _get_data_format(year):
     if year >= 2001:
         return "format5"
-    if 1997 <= year <= 2000:
-        return "format4"
-    return "format2"
+    return "format4" if 1997 <= year <= 2000 else "format2"
 
 
 def _get_data_url(year):
-    current_year, current_week = _week_number(datetime.date.today())
+    current_year, _ = _week_number(datetime.date.today())
     if year == current_year:
         return ("https://ftp.cpc.ncep.noaa.gov/htdocs/temp4/current.data", True)
     if year == current_year - 1:
         url = (
-            "https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s-PRELIM"
-            % str(year)[-2:],
+            f"https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer{str(year)[-2:]}-PRELIM",
             False,
         )
         if not _url_exists(url[0]):
@@ -252,13 +237,12 @@ def _get_data_url(year):
     if year <= 1985:
         return ("https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer73-85", False)
     url = (
-        "https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s" % str(year)[-2:],
+        f"https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer{str(year)[-2:]}",
         False,
     )
     if not _url_exists(url[0]):
         url = (
-            "https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s-PRELIM"
-            % str(year)[-2:],
+            f"https://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer{str(year)[-2:]}-PRELIM",
             False,
         )
     return url
@@ -331,14 +315,12 @@ def _parse_data_file(data_file, palmer_format, year, current_year_flag):
         ("cmi", "f8"),
     ]
 
-    decodef = lambda x: x.decode("utf-8")
     data_array = np.genfromtxt(
         data_file, dtype=dtype, delimiter=delim_sequence, usecols=use_columns
     )
     if not current_year_flag:
         data_array["year"] = year
-    dataframe = pandas.DataFrame(data_array)
-    return dataframe
+    return pandas.DataFrame(data_array)
 
 
 def _periods_for_range(start_date, end_date):
@@ -358,7 +340,7 @@ def _reindex_data(dataframe):
 
 
 def _url_exists(url):
-    return requests.head(url).status_code == 200
+    return requests.head(url, timeout=10).status_code == 200
 
 
 def _value_dict(value):
