@@ -1,24 +1,25 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.lcra.hydromet.core
-    ~~~~~~~~~~~~~~~~~~~~~~~
-    This module provides access to hydrologic and climate data in the Colorado
-    River Basin (Texas) provided by the `Lower Colorado River Authority`_
-    `Hydromet`_ web site and web service.
+ulmo.lcra.hydromet.core
+~~~~~~~~~~~~~~~~~~~~~~~
+This module provides access to hydrologic and climate data in the Colorado
+River Basin (Texas) provided by the `Lower Colorado River Authority`_
+`Hydromet`_ web site and web service.
 
-    .. _Lower Colorado River Authority: http://www.lcra.org
-    .. _Hydromet: http://hydromet.lcra.org
+.. _Lower Colorado River Authority: http://www.lcra.org
+.. _Hydromet: http://hydromet.lcra.org
 """
+
 import datetime
 import logging
 
+import numpy as np
 import pandas
 import requests
 from bs4 import BeautifulSoup
 from dateutil.relativedelta import relativedelta
 from geojson import Feature, FeatureCollection, Point
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 # configure logging
 LOG_FORMAT = "%(message)s"
@@ -26,8 +27,8 @@ logging.basicConfig(format=LOG_FORMAT)
 log = logging.getLogger(__name__)
 log.setLevel(logging.INFO)
 
-historical_data_url = "https://hydromet.lcra.org/chronhist.aspx"
-current_data_url = "https://hydrometdata.lcra.org"
+HISTORICAL_DATA_URL = "https://hydromet.lcra.org/chronhist.aspx"
+CURRENT_DATA_URL = "https://hydrometdata.lcra.org"
 PARAMETERS = {
     "stage": "the level of water above a benchmark in feet",
     "flow": "streamflow in cubic feet per second",
@@ -46,7 +47,7 @@ current_data_services = ["GetLowerBasin", "GetUpperBasin"]
 # stage measurements in lake and stream, the LCRA uses 'stage' for stream sites
 # and 'lake' for lake sites
 site_types = PARAMETERS.copy()
-site_types.update({"lake": "stage measurement in lakes"})
+site_types["lake"] = "stage measurement in lakes"
 
 # for this dam sites, stage is named head or tail
 dam_sites = ["1995", "1999", "2958", "2999", "3963", "3999"]
@@ -66,7 +67,6 @@ def get_sites_by_type(site_type):
     sites_dict: dict
         A python dict with four char long site codes mapped to site information.
     """
-    sites_base_url = "https://hydromet.lcra.org/navgagelist.asp?Stype=%s"
     # the url doesn't provide list of sites for the following parameters but
     # they are available with the paired parameter. e.g., flow is available
     # at stage sites.
@@ -77,28 +77,27 @@ def get_sites_by_type(site_type):
     if site_type == "tds":
         site_type = "cndvty"
 
-    if site_type not in site_types.keys():
+    if site_type not in site_types:
         return {}
 
-    res = requests.get(sites_base_url % site_type)
+    res = requests.get(
+        f"https://hydromet.lcra.org/navgagelist.asp?Stype={site_type}", timeout=10
+    )
     soup = BeautifulSoup(res.content, "html")
     sites_str = [
         site.text.replace("&nbsp", "").replace("\xa0", "") for site in soup.findAll("a")
     ]
-    sites_dict = {s[:4]: s[7:] for s in sites_str}
-
-    return sites_dict
+    return {s[:4]: s[7:] for s in sites_str}
 
 
 def get_all_sites():
     """Returns list of all LCRA hydromet sites as geojson featurecollection."""
     sites_url = "https://hydromet.lcra.org/data/datafull.xml"
-    res = requests.get(sites_url)
+    res = requests.get(sites_url, timeout=10)
     soup = BeautifulSoup(res.content, "xml")
     rows = soup.findAll("row")
     features = [_create_feature(row) for row in rows]
-    sites = FeatureCollection(features)
-    return sites
+    return FeatureCollection(features)
 
 
 def get_current_data(service, as_geojson=False):
@@ -116,7 +115,7 @@ def get_current_data(service, as_geojson=False):
 
     Returns
     -------
-    current_values_dicts : a list of dicts or
+        current_values_dicts : a list of dicts or
         current_values_geojson : a geojson featurecollection.
     """
     request_body_template = (
@@ -125,7 +124,7 @@ def get_current_data(service, as_geojson=False):
         'xmlns:xsd="http://www.w3.org/2001/XMLSchema" '
         'xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">\n '
         "  <soap12:Body>\n"
-        '    <%s xmlns="https://hydrometdata.lcra.org" />\n'
+        '    <%s xmlns="http://hydrometdata.lcra.org" />\n'
         "  </soap12:Body> \n"
         "</soap12:Envelope>"
     )
@@ -134,32 +133,29 @@ def get_current_data(service, as_geojson=False):
     elif service.lower() == "getlowerbasin":
         service = "GetLowerBasin"
     else:
-        log.info("service %s not recognized" % service)
+        log.info(f"service {service} not recognized")
         return {}
     request_body = request_body_template % service
     headers = {"Content-Type": "text/xml; charset=utf-8"}
-    res = requests.post(current_data_url, data=request_body, headers=headers)
+    res = requests.post(
+        CURRENT_DATA_URL, data=request_body, headers=headers, timeout=10
+    )
     if res.status_code != 200:
-        log.info("http request failed with status code %s" % res.status_code)
+        log.info(f"http request failed with status code {res.status_code}")
         return {}
     soup = BeautifulSoup(res.content)
-    sites_els = soup.findAll("cls%s" % service.lower().replace("get", ""))
+    sites_els = soup.findAll(f"cls{service.lower().replace('get', '')}")
     current_values_dicts = [_parse_current_values(site_el) for site_el in sites_els]
-    if as_geojson:
-        features = []
-        for value_dict in current_values_dicts:
-            feature = _feature_for_values_dict(value_dict)
-            if len(feature):
-                features.append(feature[0])
-        if len(features) != len(current_values_dicts):
-            log.warn("some of the sites did not location information")
-        if features:
-            current_values_geojson = FeatureCollection(features)
-            return current_values_geojson
-        else:
-            return {}
-    else:
+    if not as_geojson:
         return current_values_dicts
+    features = []
+    for value_dict in current_values_dicts:
+        feature = _feature_for_values_dict(value_dict)
+        if len(feature):
+            features.append(feature[0])
+    if len(features) != len(current_values_dicts):
+        log.warn("some of the sites did not location information")
+    return FeatureCollection(features) if features else {}
 
 
 def get_site_data(
@@ -197,10 +193,10 @@ def get_site_data(
     values_dict : dict
     """
     parameter_code = parameter_code.upper()
-    if parameter_code.lower() not in PARAMETERS.keys():
-        log.info("%s is not an LCRA parameter" % parameter_code)
+    if parameter_code.lower() not in PARAMETERS:
+        log.info(f"{parameter_code} is not an LCRA parameter")
         return None
-    initial_request = requests.get(historical_data_url, verify=False)
+    initial_request = requests.get(HISTORICAL_DATA_URL, timeout=10)
     if initial_request.status_code != 200:
         return None
     list_request_headers = {
@@ -208,24 +204,21 @@ def get_site_data(
         "DropDownList1": site_code,
     }
     list_request = _make_next_request(
-        historical_data_url, initial_request, list_request_headers
+        HISTORICAL_DATA_URL, initial_request, list_request_headers
     )
     if list_request.status_code != 200:
         return None
 
-    if parameter_code == "STAGE":
-        if site_code in dam_sites:
-            parameter_code = dam_site_location.upper()
-        else:
-            parameter_code = "STAGE"
+    if parameter_code == "STAGE" and site_code in dam_sites:
+        parameter_code = dam_site_location.upper()
+    elif (
+        parameter_code == "STAGE"
+        or parameter_code != "RHUMID"
+        and parameter_code == "FLOW"
+    ):
+        parameter_code = "STAGE"
     elif parameter_code == "RHUMID":
         parameter_code = "Rhumid"
-    # the parameter selection dropdown doesn't have flow. the data comes with stage.
-    elif parameter_code == "FLOW":
-        parameter_code = "STAGE"
-    else:
-        pass
-
     if start_date is None:
         start_date = datetime.date.today()
     if end_date is None:
@@ -238,14 +231,13 @@ def get_site_data(
             return None
     else:
         values_dict = []
-        chunks = pandas.np.ceil((end_date - start_date).days / 180.0)
-        for chunk in pandas.np.arange(chunks) + 1:
+        chunks = np.ceil((end_date - start_date).days / 180.0)
+        for chunk in np.arange(chunks) + 1:
             request_start_date = start_date + relativedelta(days=180 * (chunk - 1))
             chunk_end_date = start_date + relativedelta(days=180 * chunk)
-            if chunk_end_date >= end_date:
-                request_end_date = end_date
-            else:
-                request_end_date = chunk_end_date
+            request_end_date = (
+                end_date if chunk_end_date >= end_date else chunk_end_date
+            )
             log.info(
                 "getting chunk: %i, start: %s, end: %s, parameter: %s"
                 % (chunk, request_start_date, request_end_date, parameter_code)
@@ -261,28 +253,23 @@ def get_site_data(
 
     df = _values_dict_to_df(values_dict).astype(float)
 
-    if not as_dataframe:
-        return df.to_dict("records")
-    else:
-        return df
+    return df if as_dataframe else df.to_dict("records")
 
 
 def _create_feature(row):
     geometry = Point((float(row["e"]), float(row["d"])))
     site_props = dict(site_code=row["a"], site_description=row["c"])
-    site = Feature(geometry=geometry, properties=site_props)
-    return site
+    return Feature(geometry=geometry, properties=site_props)
 
 
 def _feature_for_values_dict(site_values_dict):
     sites = get_all_sites()["features"]
-    site = [
+    return [
         _update_feature_props(site, site_values_dict)
         for site in sites
         if site["properties"]["site_description"].lower()
         == site_values_dict["location"].lower()
     ]
-    return site
 
 
 def _parse_current_values(site_el):
@@ -290,19 +277,17 @@ def _parse_current_values(site_el):
     site_values = {}
     for value_el in site_value_els:
         if value_el.name.lower() == "datetime":
-            if value_el.get_text().strip() == "":
-                site_values[value_el.name.lower()] = None
-            else:
-                site_values[value_el.name.lower()] = util.convert_datetime(
-                    value_el.get_text()
-                )
+            site_values[value_el.name.lower()] = (
+                None
+                if value_el.get_text().strip() == ""
+                else util.convert_datetime(value_el.get_text())
+            )
         elif value_el.name.lower() == "location":
             site_values[value_el.name.lower()] = value_el.get_text().strip()
+        elif value_el.get_text().strip() == "":
+            site_values[value_el.name.lower()] = None
         else:
-            if value_el.get_text().strip() == "":
-                site_values[value_el.name.lower()] = None
-            else:
-                site_values[value_el.name.lower()] = float(value_el.get_text())
+            site_values[value_el.name.lower()] = float(value_el.get_text())
     return site_values
 
 
@@ -312,9 +297,9 @@ def _values_dict_to_df(values_dict):
     df = pandas.DataFrame(values_dict)
     df.index = df["Date - Time"].apply(util.convert_datetime)
     df.drop("Date - Time", axis=1, inplace=True)
-    df.sort_index(inplace=True)
-    df.dropna(axis=1, how="all", inplace=True)
-    df.dropna(axis=0, how="all", inplace=True)
+    df = df.sort_index()
+    df = df.dropna(axis=1, how="all")
+    df = df.dropna(axis=0, how="all")
     return df
 
 
@@ -333,7 +318,7 @@ def _get_data(site_code, parameter_code, list_request, start, end):
 
     data_request_headers["DropDownList2"] = parameter_code
     data_request = _make_next_request(
-        historical_data_url, list_request, data_request_headers
+        HISTORICAL_DATA_URL, list_request, data_request_headers
     )
 
     if data_request.status_code != 200:
@@ -341,15 +326,14 @@ def _get_data(site_code, parameter_code, list_request, start, end):
 
     soup = BeautifulSoup(data_request.content, "html.parser")
     columns = [col.get_text() for col in soup.findAll("th")]
-    values_dict = [_get_row_values(row, columns) for row in soup.findAll("tr")[1:]]
-    return values_dict
+    return [_get_row_values(row, columns) for row in soup.findAll("tr")[1:]]
 
 
 def _extract_headers_for_next_request(request):
     payload = {}
     for tag in BeautifulSoup(request.content, "html.parser").findAll("input"):
         tag_dict = dict(tag.attrs)
-        if tag_dict.get("value", None) == "tabular":
+        if tag_dict.get("value") == "tabular":
             #
             continue
         # some tags don't have a value and are used w/ JS to toggle a set of checkboxes
@@ -360,15 +344,14 @@ def _extract_headers_for_next_request(request):
 def _make_next_request(url, previous_request, data):
     data_headers = _extract_headers_for_next_request(previous_request)
     data_headers.update(data)
-    return requests.post(url, cookies=previous_request.cookies, data=data_headers)
+    return requests.post(
+        url, cookies=previous_request.cookies, data=data_headers, timeout=10
+    )
 
 
 def _parse_val(val):
     # the &nsbp translates to the following unicode
-    if val == "\xa0":
-        return None
-    else:
-        return val
+    return None if val == "\xa0" else val
 
 
 def _update_feature_props(feature, props):
