@@ -1,22 +1,25 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.lcra.waterquality.core
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    This module provides access to data provided by the `Lower Colorado
-    River Authority`_ `Water Quality`_ web site.
+ulmo.lcra.waterquality.core
+~~~~~~~~~~~~~~~~~~~~~~~~~~~
+This module provides access to data provided by the `Lower Colorado
+River Authority`_ `Water Quality`_ web site.
 
-    .. _Lower Colorado River Authority: http://www.lcra.org
-    .. _Water Quality: http://waterquality.lcra.org/
+.. _Lower Colorado River Authority: http://www.lcra.org
+.. _Water Quality: http://waterquality.lcra.org/
 """
+
 import logging
 
 # import datetime
 import os.path as op
 
+import numpy as np
+import pandas as pd
+import requests
 from bs4 import BeautifulSoup
 from geojson import Feature, FeatureCollection, Point
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 # import unicode
 
@@ -26,9 +29,6 @@ LCRA_WATERQUALITY_DIR = op.join(util.get_ulmo_dir(), "lcra/waterquality")
 
 log = logging.getLogger(__name__)
 
-import numpy as np
-import pandas as pd
-import requests
 
 source_map = {
     "LCRA": "Lower Colorado River Authority",
@@ -65,8 +65,8 @@ def get_sites(source_agency=None):
     -------
     sites_geojson : geojson FeatureCollection
     """
-    sites_url = "http://waterquality.lcra.org/"
-    response = requests.get(sites_url, verify=False)
+    sites_url = "https://waterquality.lcra.org/"
+    response = requests.get(sites_url, timeout=60)
     lines = response.content.decode("utf-8").split("\n")
     sites_unprocessed = [
         line.strip().strip("createMarker").strip("(").strip(")").split(",")
@@ -75,21 +75,20 @@ def get_sites(source_agency=None):
     ]
     sites = [_create_feature(site_info) for site_info in sites_unprocessed]
     if source_agency:
-        if not source_agency.upper() in source_map.keys():
-            log.info("the source %s is not recognized" % source_agency)
+        if source_agency.upper() not in source_map:
+            log.info(f"the source {source_agency} is not recognized")
             return {}
         sites = [
             site
             for site in sites
             if site["properties"]["source"] == source_map[source_agency.upper()]
         ]
-    sites_geojson = FeatureCollection(sites)
-
-    return sites_geojson
+    return FeatureCollection(sites)
 
 
 def get_historical_data(site_code, start=None, end=None, as_dataframe=False):
-    """Fetches data for a site at a given date.
+    """
+    Fetch data for a site at a given date.
 
     Parameters
     ----------
@@ -111,6 +110,7 @@ def get_historical_data(site_code, start=None, end=None, as_dataframe=False):
     data_dict : dict
         A dict containing site information and values.
     """
+
     if isinstance(site_code, (str)):
         pass
     elif isinstance(site_code, (int)):
@@ -120,14 +120,16 @@ def get_historical_data(site_code, start=None, end=None, as_dataframe=False):
             "Unsure of the site_code parameter type. \
                 Try string or int"
         )
-        raise
+        raise ValueError(
+            f"Unsure of the site_code parameter type. Got {site_code}. Try string or int"
+        )
 
     waterquality_url = (
-        "http://waterquality.lcra.org/parameter.aspx?qrySite=%s" % site_code
+        f"http://waterquality.lcra.org/parameter.aspx?qrySite={site_code}"
     )
     waterquality_url2 = "http://waterquality.lcra.org/events.aspx"
 
-    initial_request = requests.get(waterquality_url)
+    initial_request = requests.get(waterquality_url, timeout=60)
     initialsoup = BeautifulSoup(initial_request.content, "html.parser")
 
     sitevals = [
@@ -151,22 +153,18 @@ def get_historical_data(site_code, start=None, end=None, as_dataframe=False):
     # uses \xa0 for blank
 
     for row in gridview.findAll("tr"):
-        vals = [_parse_val(aux.text) for aux in row.findAll("td")]
-        if len(vals) == 0:
-            continue
-        results.append(dict(zip(headers, vals)))
+        if vals := [_parse_val(aux.text) for aux in row.findAll("td")]:
+            results.append(dict(zip(headers, vals)))
 
     data = _create_dataframe(results)
 
     if start and not data.empty:
-        data = data.loc[util.convert_date(start) :]
+        data = data.ix[util.convert_date(start) :]
 
     if end and not data.empty:
-        data = data.loc[: util.convert_date(end)]
+        data = data.ix[: util.convert_date(end)]
 
-    if as_dataframe:
-        return data
-    return data.to_dict(orient="records")
+    return data if as_dataframe else data.to_dict(orient="records")
 
 
 def get_recent_data(site_code, as_dataframe=False):
@@ -187,15 +185,12 @@ def get_recent_data(site_code, as_dataframe=False):
     list
         list of values or dataframe.
     """
-    if site_code not in real_time_sites.keys():
-        log.info("%s is not in the list of LCRA real time salinity sites" % site_code)
+    if site_code not in real_time_sites:
+        log.info(f"{site_code} is not in the list of LCRA real time salinity sites")
         return {}
-    data_url = "http://waterquality.lcra.org/salinity.aspx?sNum={}&name={}".format(
-        site_code,
-        real_time_sites[site_code],
-    )
+    data_url = f"http://waterquality.lcra.org/salinity.aspx?sNum={site_code}&name={real_time_sites[site_code]}"
     data = pd.read_html(data_url, header=0)[1]
-    data.index = data["Date - Time"].apply(lambda x: util.convert_datetime(x))
+    data.index = data["Date - Time"].apply(util.convert_datetime)
     data.drop("Date - Time", axis=1, inplace=True)
     data = data.applymap(_nan_values)
     data.dropna(how="all", axis=0, inplace=True)
@@ -204,20 +199,16 @@ def get_recent_data(site_code, as_dataframe=False):
     data.rename(columns=columns, inplace=True)
     data = data.astype(float)
 
-    if as_dataframe:
-        return data
-    return util.dict_from_dataframe(data)
+    return data if as_dataframe else util.dict_from_dataframe(data)
 
 
 def _nan_values(value):
-    if value == -998.0 or value == "--":
-        return np.nan
-    return value
+    return np.nan if value in [-998.0, "--"] else value
 
 
-def _beautify_header(str):
+def _beautify_header(input_str):
     return (
-        str.replace("\xb0", "deg")
+        input_str.replace("\xb0", "deg")
         .lower()
         .replace("(", "")
         .replace(")", "")
@@ -229,12 +220,11 @@ def _beautify_header(str):
 
 def get_site_info(site_code):
     sites = get_sites()
-    site = [
+    return [
         site
         for site in sites["features"]
         if site_code == site["properties"]["site_code"]
     ]
-    return site
 
 
 def _create_dataframe(results):
@@ -263,7 +253,7 @@ def _extract_headers_for_next_request(request):
     payload = {}
     for tag in BeautifulSoup(request.content, "html.parser").findAll("input"):
         tag_dict = dict(tag.attrs)
-        if tag_dict.get("value", None) == "tabular":
+        if tag_dict.get("value") == "tabular":
             #
             continue
         # some tags don't have a value and are used w/ JS to toggle a set of checkboxes
@@ -279,34 +269,33 @@ def _get_source(site_type_code):
         "LCAU": "COA",
         "WCFO": "TCEQ",
     }
-    if site_type_code not in internal_source_abbr.keys():
+    if site_type_code not in internal_source_abbr:
         return None
     return source_map.get(internal_source_abbr[site_type_code])
 
 
 def _get_parameter(site_type_code):
-    if site_type_code == "Salinity" or site_type_code == "Conductivity":
+    if site_type_code in ["Salinity", "Conductivity"]:
         return site_type_code
-    return None
+    else:
+        return None
 
 
 def _get_water_body(site_type_code):
-    if site_type_code == "Bay":
-        return "Bay"
-    return None
+    return "Bay" if site_type_code == "Bay" else None
 
 
 def _make_next_request(url, previous_request, data):
     data_headers = _extract_headers_for_next_request(previous_request)
     data_headers.update(data)
-    return requests.post(url, cookies=previous_request.cookies, data=data_headers)
+    return requests.post(
+        url, cookies=previous_request.cookies, data=data_headers, timeout=60
+    )
 
 
 def _parse_val(val):
     # the &nsbp translates to the following unicode
-    if val == "\xa0":
-        return None
-    return val
+    return None if val == "\xa0" else val
 
 
 def _parse_site_str(site_str):
@@ -323,6 +312,4 @@ def _parse_site_str(site_str):
 
 
 def _real_time(site_type_code):
-    if site_type_code == "Salinity" or site_type_code == "Conductivity":
-        return True
-    return False
+    return site_type_code in ["Salinity", "Conductivity"]
