@@ -1,20 +1,20 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.ncdc.cirs.core
-    ~~~~~~~~~~~~~~~~~~~
+ulmo.ncdc.cirs.core
+~~~~~~~~~~~~~~~~~~~
 
-    This module provides direct access to the `National Climatic Data Center`_
-    `Climate Index Reference Sequential (CIRS)`_ drought dataset.
+This module provides direct access to the `National Climatic Data Center`_
+`Climate Index Reference Sequential (CIRS)`_ drought dataset.
 
-    .. _National Climatic Data Center: http://www.ncdc.noaa.gov
-    .. _Climate Index Reference Sequential (CIRS): http://www1.ncdc.noaa.gov/pub/data/cirs/
+.. _National Climatic Data Center: http://www.ncdc.noaa.gov
+.. _Climate Index Reference Sequential (CIRS): http://www1.ncdc.noaa.gov/pub/data/cirs/
 """
-import distutils
+
 import os.path
 
-import pandas
+import pandas as pd
+from packaging.version import Version
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 CIRS_DIR = util.get_ulmo_dir("ncdc/cirs")
 
@@ -95,6 +95,7 @@ def get_data(
         A list of value dicts or a pandas.DataFrame containing data. See
         the ``as_dataframe`` parameter for more.
     """
+
     if isinstance(elements, str):
         elements = [elements]
     elif elements is None:
@@ -124,22 +125,18 @@ def get_data(
         element_df = _get_element_data(element, by_state, element_file, location_names)
 
         keys = ["location_code", "year", "month"]
-        for append_key in ["division", "state", "state_code"]:
-            if append_key in element_df.columns:
-                keys.append(append_key)
+        keys.extend(
+            append_key
+            for append_key in ["division", "state", "state_code"]
+            if append_key in element_df.columns
+        )
         element_df.set_index(keys, inplace=True)
 
-        if df is None:
-            df = element_df
-        else:
-            df = df.join(element_df, how="outer")
-
+        df = element_df if df is None else df.join(element_df, how="outer")
     df = df.reset_index()
     df = _resolve_location_names(df, location_names, by_state)
 
-    if as_dataframe:
-        return df
-    return list(df.T.to_dict().values())
+    return df if as_dataframe else list(df.T.to_dict().values())
 
 
 def _get_element_data(element, by_state, use_file, location_names):
@@ -158,19 +155,15 @@ def _get_element_data(element, by_state, use_file, location_names):
 
 
 def _get_element_file(use_file, element, elements, by_state):
-    if isinstance(use_file, str):
-        if os.path.basename(use_file) == "":
-            if len(elements) > 1:
-                if not ValueError(
-                    "'use_file' must be a path to a directory if using "
-                    "'use_file' with multiple elements"
-                ):
-                    raise AssertionError
-
-            return use_file + _get_filename(
-                element, by_state, os.path.dirname(use_file)
+    if isinstance(use_file, str) and os.path.basename(use_file) == "":
+        if len(elements) > 1:
+            assert ValueError(
+                "'use_file' must be a path to a directory if using "
+                "'use_file' with multiple elements"
             )
 
+        return use_file + _get_filename(element, by_state, os.path.dirname(use_file))
+
     return use_file
 
 
@@ -188,17 +181,14 @@ def _get_url(element, by_state):
 
 def _most_recent(files, element, by_state):
     geographic_extent = "st" if by_state else "dv"
-    match_str = "climdiv-{element}{geographic_extent}".format(
-        element=element,
-        geographic_extent=geographic_extent,
-    )
+    match_str = f"climdiv-{element}{geographic_extent}"
     matches = [s for s in files if s.startswith(match_str)]
     return sorted(matches, key=_file_key)[0]
 
 
 def _file_key(filename):
     version_str = filename.split("-")[2][1:]
-    return distutils.version.StrictVersion(version_str)
+    return Version(version_str)
 
 
 def _parse_values(file_handle, by_state, location_names, element):
@@ -230,7 +220,7 @@ def _parse_values(file_handle, by_state, location_names, element):
     parsed = util.parse_fwf(file_handle, columns, na_values=na_values)
 
     month_columns = [id_column[0] for id_column in id_columns]
-    melted = pandas.melt(parsed, id_vars=month_columns).rename(
+    melted = pd.melt(parsed, id_vars=month_columns).rename(
         columns={"variable": "month"}
     )
 
@@ -239,19 +229,17 @@ def _parse_values(file_handle, by_state, location_names, element):
     # throw away NaNs
     melted = melted[melted["value"].notnull()]
 
-    data = melted.rename(
+    return melted.rename(
         columns={
             "value": element,
         }
     )
 
-    return data
-
 
 def _resolve_location_names(df, location_names, by_state):
     if location_names is None:
         return df
-    if location_names not in ("abbr", "full"):
+    elif location_names not in ("abbr", "full"):
         raise ValueError(
             "location_names should be set to either None, 'abbr' or 'full'"
         )
@@ -265,12 +253,13 @@ def _resolve_location_names(df, location_names, by_state):
                     location_names: "location",
                 }
             )
-        return with_locations.rename(
-            columns={
-                location_names: "state",
-                "location_code": "state_code",
-            }
-        )
+        else:
+            return with_locations.rename(
+                columns={
+                    location_names: "state",
+                    "location_code": "state_code",
+                }
+            )
 
 
 def _states_regions_dataframe():
@@ -388,4 +377,4 @@ def _states_regions_dataframe():
         462: ("% Prod: Soybean Belt", "%prod:sb"),
         465: ("% Prod: Cotton Belt", "%prod:cb"),
     }
-    return pandas.DataFrame(STATES_REGIONS).T.rename(columns={0: "full", 1: "abbr"})
+    return pd.DataFrame(STATES_REGIONS).T.rename(columns={0: "full", 1: "abbr"})
