@@ -1,23 +1,23 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.ncdc.ghcn_daily.core
-    ~~~~~~~~~~~~~~~~~~~~~~~~~
+ulmo.ncdc.ghcn_daily.core
+~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides direct access to `National Climatic Data Center`_
-    `Global Historical Climate Network - Daily`_ dataset.
+This module provides direct access to `National Climatic Data Center`_
+`Global Historical Climate Network - Daily`_ dataset.
 
 
-    .. _National Climatic Data Center: http://www.ncdc.noaa.gov
-    .. _Global Historical Climate Network - Daily: http://www.ncdc.noaa.gov/oa/climate/ghcn-daily/
+.. _National Climatic Data Center: http://www.ncdc.noaa.gov
+.. _Global Historical Climate Network - Daily: http://www.ncdc.noaa.gov/oa/climate/ghcn-daily/
 
 """
+
 import itertools
 import os
 
 import numpy as np
 import pandas
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 GHCN_DAILY_DIR = os.path.join(util.get_ulmo_dir(), "ncdc/ghcn_daily")
 
@@ -25,6 +25,7 @@ GHCN_DAILY_DIR = os.path.join(util.get_ulmo_dir(), "ncdc/ghcn_daily")
 def get_data(station_id, elements=None, update=True, as_dataframe=False):
     """Retrieves data for a given station.
 
+
     Parameters
     ----------
     station_id : str
@@ -43,6 +44,7 @@ def get_data(station_id, elements=None, update=True, as_dataframe=False):
         internally, so setting this to ``True`` is a little bit faster as it
         skips a serialization step.
 
+
     Returns
     -------
     site_dict : dict
@@ -72,7 +74,7 @@ def get_data(station_id, elements=None, update=True, as_dataframe=False):
                     for name, start, end, converter in value_columns
                 ]
                 for n in range(1, 32)
-            ]
+            ],
         )
     )
 
@@ -82,11 +84,11 @@ def get_data(station_id, elements=None, update=True, as_dataframe=False):
     dataframes = {}
 
     for element_name, element_df in station_data.groupby("element"):
-        if not elements is None and element_name not in elements:
+        if elements is not None and element_name not in elements:
             continue
 
         element_df["month_period"] = element_df.apply(
-            lambda x: pandas.Period("{}-{}".format(x["year"], x["month"])), axis=1
+            lambda x: pandas.Period(f"{x['year']}-{x['month']}"), axis=1
         )
         element_df = element_df.set_index("month_period")
         monthly_index = element_df.index
@@ -115,16 +117,17 @@ def get_data(station_id, elements=None, update=True, as_dataframe=False):
             months = pandas.PeriodIndex([pandas.Period(date, "M") for date in dates])
             for column_name in dataframe.columns:
                 col = column_name + str(day_of_month)
-                dataframe[column_name][dates] = element_df[col][months]
+                dataframe[column_name][dates] = element_df[col][months].values
 
         dataframes[element_name] = dataframe
 
     if as_dataframe:
         return dataframes
-    return {
-        key: util.dict_from_dataframe(dataframe)
-        for key, dataframe in dataframes.items()
-    }
+    else:
+        return {
+            key: util.dict_from_dataframe(dataframe)
+            for key, dataframe in dataframes.items()
+        }
 
 
 def get_stations(
@@ -138,6 +141,7 @@ def get_stations(
 ):
     """Retrieves station information, optionally limited to specific parameters.
 
+
     Parameters
     ----------
     country : str
@@ -169,12 +173,14 @@ def get_stations(
         returned. The pandas dataframe is used internally, so setting this to
         ``True`` is a little bit faster as it skips a serialization step.
 
+
     Returns
     -------
     stations_dict : dict or pandas.DataFrame
         A dict or pandas.DataFrame representing station information for stations
         matching the arguments. See the ``as_dataframe`` parameter for more.
     """
+
     columns = [
         ("country", 0, 2, None),
         ("network", 2, 3, None),
@@ -192,17 +198,17 @@ def get_stations(
     stations_file = _get_ghcn_file("ghcnd-stations.txt", check_modified=update)
     stations = util.parse_fwf(stations_file, columns)
 
-    if not country is None:
+    if country is not None:
         stations = stations[stations["country"] == country]
-    if not state is None:
+    if state is not None:
         stations = stations[stations["state"] == state]
 
     # set station id and index by it
     stations["id"] = stations[["country", "network", "network_id"]].T.apply("".join)
 
-    if not elements is None or not start_year is None or not end_year is None:
+    if elements is not None or start_year is not None or end_year is not None:
         inventory = _get_inventory(update=update)
-        if not elements is None:
+        if elements is not None:
             if isinstance(elements, str):
                 elements = [elements]
 
@@ -210,9 +216,9 @@ def get_stations(
             for element in elements:
                 mask += inventory["element"] == element
             inventory = inventory[mask]
-        if not start_year is None:
+        if start_year is not None:
             inventory = inventory[inventory["last_year"] >= start_year]
-        if not end_year is None:
+        if end_year is not None:
             inventory = inventory[inventory["first_year"] <= end_year]
 
         uniques = inventory["id"].unique()
@@ -234,9 +240,7 @@ def get_stations(
         is_invalid = is_nan | is_empty
         stations.loc[is_invalid, "wm_oid"] = np.nan
 
-    if as_dataframe:
-        return stations
-    return util.dict_from_dataframe(stations)
+    return stations if as_dataframe else util.dict_from_dataframe(stations)
 
 
 def _get_ghcn_file(filename, check_modified=True):
@@ -244,7 +248,7 @@ def _get_ghcn_file(filename, check_modified=True):
     if "ghcnd-" in filename:
         url = base_url + filename
     else:
-        url = base_url + "all/" + filename
+        url = f"{base_url}all/{filename}"
 
     path = os.path.join(GHCN_DAILY_DIR, url.split("/")[-1])
     util.download_if_new(url, path, check_modified=check_modified)
