@@ -1,14 +1,14 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.ncdc.gsod.core
-    ~~~~~~~~~~~~~~~~~~~
+ulmo.ncdc.gsod.core
+~~~~~~~~~~~~~~~~~~~
 
-    This module provides direct access to `National Climatic Data Center`_
-    `Global Summary of the Day`_ dataset.
+This module provides direct access to `National Climatic Data Center`_
+`Global Summary of the Day`_ dataset.
 
-    .. _National Climatic Data Center: http://www.ncdc.noaa.gov
-    .. _Global Summary of the Day: http://www.ncdc.noaa.gov/oa/gsod.html
+.. _National Climatic Data Center: http://www.ncdc.noaa.gov
+.. _Global Summary of the Day: http://www.ncdc.noaa.gov/oa/gsod.html
 """
+
 import csv
 import datetime
 import gzip
@@ -18,7 +18,7 @@ import tarfile
 
 import numpy as np
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 NCDC_GSOD_DIR = os.path.join(util.get_ulmo_dir(), "ncdc/gsod")
 NCDC_GSOD_STATIONS_FILE = os.path.join(NCDC_GSOD_DIR, "isd-history.csv")
@@ -32,13 +32,14 @@ def get_parameters():
 
     Parameters
     ----------
-    None
+        None
 
     Returns
     -------
-    dictionary of variables with parameter codes as keys
+        dictionary of variables with parameter codes as keys
         and GSOD codes as values.
     """
+
     VARIABLES = {
         "mean_temp": "TEMP",
         "mean_temp_count": "TEMP",
@@ -67,7 +68,9 @@ def get_parameters():
 
 
 def get_data(station_codes, start=None, end=None, parameters=None):
-    """Retrieves data for a set of stations.
+    """
+    Retrieve data for a set of stations.
+
 
     Parameters
     ----------
@@ -85,17 +88,11 @@ def get_data(station_codes, start=None, end=None, parameters=None):
     data_dict : dict
         Dict with station codes keyed to lists of value dicts.
     """
-    if start:
-        start_date = util.convert_date(start)
-    else:
-        start_date = NCDC_GSOD_START_DATE
-    if end:
-        end_date = util.convert_date(end)
-    else:
-        end_date = datetime.date.today()
+    start_date = util.convert_date(start) if start else NCDC_GSOD_START_DATE
+    end_date = util.convert_date(end) if end else datetime.date.today()
     if isinstance(parameters, str):
         parameters = [parameters]
-    if parameters and not "date" in parameters:
+    if parameters and "date" not in parameters:
         # add date to list of parameters if it's not there already
         parameters.insert(0, "date")
     if isinstance(station_codes, str):
@@ -122,7 +119,7 @@ def get_data(station_codes, start=None, end=None, parameters=None):
                 year_data = _read_gsod_file(gsod_tar, station, year)
                 if parameters:
                     year_data = _subset_record_array(year_data, parameters)
-                if not year_data is None:
+                if year_data is not None:
                     # apply date ranges if they exist
                     if start_date or end_date:
                         mask = np.ones(len(year_data), dtype=bool)
@@ -132,14 +129,14 @@ def get_data(station_codes, start=None, end=None, parameters=None):
                             mask = mask & (year_data["date"] <= end_date)
                         year_data = year_data[mask]
 
-                    if not data_dict[station] is None:
+                    if data_dict[station] is not None:
                         # XXX: this could be more efficient for large numbers
                         # of years with a list comprehension or generator
                         data_dict[station] = np.append(data_dict[station], year_data)
                     else:
                         data_dict[station] = year_data
     for station, data_array in data_dict.items():
-        if not data_dict[station] is None:
+        if data_dict[station] is not None:
             data_dict[station] = _record_array_to_value_dicts(data_array)
     return data_dict
 
@@ -147,6 +144,7 @@ def get_data(station_codes, start=None, end=None, parameters=None):
 def get_stations(country=None, state=None, start=None, end=None, update=True):
     """Retrieve information on the set of available stations.
 
+
     Parameters
     ----------
     country : {``None``, str, or iterable}
@@ -167,20 +165,14 @@ def get_stations(country=None, state=None, start=None, end=None, update=True):
         then a new stations file will only be downloaded if a previously
         downloaded file cannot be found.
 
+
     Returns
     -------
     stations_dict : dict
         A dict with USAF-WBAN codes keyed to station information dicts.
     """
-    if start:
-        start_date = util.convert_date(start)
-    else:
-        start_date = None
-    if end:
-        end_date = util.convert_date(end)
-    else:
-        end_date = None
-
+    start_date = util.convert_date(start) if start else None
+    end_date = util.convert_date(end) if end else None
     if isinstance(country, str):
         country = [country]
     if isinstance(state, str):
@@ -193,14 +185,8 @@ def get_stations(country=None, state=None, start=None, end=None, update=True):
         if country is None and state is None and start is None and end is None:
             rows = reader
         else:
-            if start_date is None:
-                start_str = None
-            else:
-                start_str = start_date.strftime("%Y%m%d")
-            if end_date is None:
-                end_str = None
-            else:
-                end_str = end_date.strftime("%Y%m%d")
+            start_str = None if start_date is None else start_date.strftime("%Y%m%d")
+            end_str = None if end_date is None else end_date.strftime("%Y%m%d")
             rows = [
                 row
                 for row in reader
@@ -228,7 +214,7 @@ def _convert_date_string(date_string):
 
 
 def _get_gsod_file(year):
-    url = "http://www1.ncdc.noaa.gov/pub/data/gsod/{}/gsod_{}.tar".format(year, year)
+    url = f"http://www1.ncdc.noaa.gov/pub/data/gsod/{year}/gsod_{year}.tar"
     filename = url.split("/")[-1]
     path = os.path.join(NCDC_GSOD_DIR, filename)
     util.download_if_new(url, path, check_modified=True)
@@ -236,13 +222,13 @@ def _get_gsod_file(year):
 
 
 def _passes_row_filter(row, country=None, state=None, start_str=None, end_str=None):
-    if not country is None and row["CTRY"] not in country:
+    if country is not None and row["CTRY"] not in country:
         return False
-    if not state is None and row["STATE"] not in state:
+    if state is not None and row["STATE"] not in state:
         return False
-    if not start_str is None and row["END"] != "" and row["END"] <= start_str:
+    if start_str is not None and row["END"] != "" and row["END"] <= start_str:
         return False
-    if not end_str is None and row["BEGIN"] != "" and end_str <= row["BEGIN"]:
+    if end_str is not None and row["BEGIN"] != "" and end_str <= row["BEGIN"]:
         return False
     return True
 
@@ -253,16 +239,22 @@ def _process_station(station_row):
         "begin": _convert_date_string(station_row["BEGIN"]),
         "icao": station_row["ICAO"],
         "country": station_row["CTRY"],
-        "elevation": round(float(station_row["ELEV(M)"]), 1)
-        if station_row["ELEV(M)"] not in ("", "-99999")
-        else None,
+        "elevation": (
+            round(float(station_row["ELEV(M)"]), 1)
+            if station_row["ELEV(M)"] not in ("", "-99999")
+            else None
+        ),
         "end": _convert_date_string(station_row["END"]),
-        "latitude": round(float(station_row["LAT"]), 3)
-        if station_row["LAT"] not in ("", "-99999")
-        else None,
-        "longitude": round(float(station_row["LON"]), 3)
-        if station_row["LON"] not in ("", "-999999")
-        else None,
+        "latitude": (
+            round(float(station_row["LAT"]), 3)
+            if station_row["LAT"] not in ("", "-99999")
+            else None
+        ),
+        "longitude": (
+            round(float(station_row["LON"]), 3)
+            if station_row["LON"] not in ("", "-999999")
+            else None
+        ),
         "name": station_row["STATION NAME"],
         "state": station_row["STATE"],
         "USAF": station_row["USAF"],
@@ -272,7 +264,7 @@ def _process_station(station_row):
 
 
 def _read_gsod_file(gsod_tar, station, year):
-    tar_station_filename = station + "-" + str(year) + ".op.gz"
+    tar_station_filename = f"{station}-{year}.op.gz"
     try:
         gsod_tar.getmember("./" + tar_station_filename)
     except KeyError:
