@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import logging
 import os
 import shutil
@@ -7,11 +6,11 @@ from datetime import datetime, timedelta
 import isodate
 import pandas as pd
 import requests
-from ulmo import util
 
+from ... import util
 from . import parsers
 
-dcs_url = "https://dcs1.noaa.gov/Account/FieldTestData"
+DCS_URL = "https://dcs1.noaa.gov/Account/FieldTestData"
 
 DEFAULT_FILE_PATH = "noaa/goes/"
 
@@ -51,7 +50,7 @@ def decode(dataframe, parser, **kwargs):
         return dataframe
 
     df = []
-    for timestamp, data in dataframe.iterrows():
+    for _, data in dataframe.iterrows():
         parsed = parser(data, **kwargs)
         parsed.dropna(how="all", inplace=True)
         if parsed.empty:
@@ -96,6 +95,7 @@ def get_data(dcp_address, hours, use_cache=False, cache_path=None, as_dataframe=
     message_data : {pandas.DataFrame, dict}
         Either a pandas dataframe or a dict indexed by dcp message times
     """
+
     if isinstance(dcp_address, list):
         dcp_address = ",".join(dcp_address)
 
@@ -105,10 +105,7 @@ def get_data(dcp_address, hours, use_cache=False, cache_path=None, as_dataframe=
         dcp_data_path = _get_store_path(cache_path, dcp_address + ".h5")
         if os.path.exists(dcp_data_path):
             data = pd.read_hdf(dcp_data_path, dcp_address)
-    params = {}
-    params["addr"] = (dcp_address,)
-    params["hours"] = (hours,)
-
+    params = {"addr": (dcp_address,), "hours": (hours,)}
     messages = _fetch_url(params)
     new_data = pd.DataFrame([_parse(row) for row in messages])
 
@@ -123,19 +120,15 @@ def get_data(dcp_address, hours, use_cache=False, cache_path=None, as_dataframe=
             shutil.move(tmp, dcp_data_path)
 
     if data.empty:
-        if as_dataframe:
-            return data
-        return {}
-
+        return data if as_dataframe else {}
     if not as_dataframe:
         data = data.T.to_dict()
     return data
 
 
 def _fetch_url(params):
-    r = requests.post(dcs_url, params=params, timeout=60)
-    messages = r.json()
-    return messages
+    r = requests.post(DCS_URL, params=params, timeout=60)
+    return r.json()
 
 
 def _format_period(period):
@@ -146,17 +139,16 @@ def _format_period(period):
     )
 
     if minutes:
-        return "now -%s minutes" % period.seconds / 60
+        return f"now -{period.seconds} minutes" / 60
 
     if hours:
-        return "now -%s hours" % period.seconds / 3600
+        return f"now -{period.seconds} hours" / 3600
 
     if days:
-        return "now -%s days" % days
+        return f"now -{days} days"
 
 
 def _format_time(timestamp):
-
     if isinstance(timestamp, str):
         if timestamp.startswith("P"):
             timestamp = isodate.parse_duration(timestamp)
@@ -165,7 +157,7 @@ def _format_time(timestamp):
 
     if isinstance(timestamp, datetime):
         return timestamp.strftime("%Y/%j %H:%M:%S")
-    if isinstance(timestamp, timedelta):
+    elif isinstance(timestamp, timedelta):
         return _format_period(timestamp)
 
 
