@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from datetime import timedelta
 
 import numpy as np
@@ -20,6 +19,7 @@ def twdb_fts(df_row, drop_dcp_metadata=True, dual_well=False):
     format examples:
     C510D20018036133614G39-0NN170WXW00097  :WL 31 #60 -72.91 -72.89 -72.89 -72.89 -72.91 -72.92 -72.93 -72.96 -72.99 -72.97 -72.95 -72.95
     """
+
     message = df_row["dcp_message"].lower()
     message_timestamp = df_row["message_timestamp_utc"]
     if _invalid_message_check(message):
@@ -35,9 +35,7 @@ def twdb_fts(df_row, drop_dcp_metadata=True, dual_well=False):
             )
             data.append(df)
         except Exception as e:
-            print(
-                "Warning: Could not parse values for channel {}: {}".format(channel, e)
-            )
+            print(f"Warning: Could not parse values for channel {channel}: {e}")
 
     df = pd.concat(data)
 
@@ -89,11 +87,7 @@ def twdb_sutron(df_row, drop_dcp_metadata=True, dual_well=False):
                 )
                 data.append(df)
             except Exception as e:
-                print(
-                    "Warning: Could not parse values for channel {}: {}".format(
-                        channel, e
-                    )
-                )
+                print(f"Warning: Could not parse values for channel {channel}: {e}")
         else:
             try:
                 channel_data = [field.strip('+-" ') for field in lsplit[3:]]
@@ -102,11 +96,7 @@ def twdb_sutron(df_row, drop_dcp_metadata=True, dual_well=False):
                 )
                 data.append(df)
             except Exception as e:
-                print(
-                    "Warning: Could not parse values for channel {}: {}".format(
-                        channel, e
-                    )
-                )
+                print(f"Warning: Could not parse values for channel {channel}: {e}")
 
     df = pd.concat(data)
 
@@ -126,6 +116,7 @@ def twdb_texuni(dataframe, drop_dcp_metadata=True, dual_well=False):
     '"\r\n+0.000,-245.3,\r\n+0.000,-245.3,\r\n+0.000,-245.3,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.4,\r\n+0.000,-245.5,\r\n+0.000,-245.5,\r\n+0.000,-245.6,\r\n+0.000,-245.6,\r\n+0.000,-245.6,\r\n+0.000,-245.6,\r\n+0.000,-245.6,\r\n+0.000,-245.6,\r\n+412.0,+2013.,+307.0,+1300.,+12.75,+0.000,-245.4,-245.3,-245.6,+29.55,'
     ' \r\n+0.000,-109.8,\r\n+0.000,-109.8,\r\n+0.000,-109.8,\r\n+0.000,-109.8,\r\n+0.000,-109.8,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-110.0,\r\n+0.000,-110.0,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-109.9,\r\n+0.000,-110.0,\r\n+0.000,-110.0,\r\n+0.000,-110.0,\r\n+0.000,-110.1,\r\n+0.000,-110.1,\r\n+0.000,-110.1,\r\n+0.000,-110.1,\r\n+0.000,-110.1,\r\n+340.0,+2013.,+307.0,+1400.,+12.07,+0.000,-109.9,-109.8,-110.1,+30.57,'
     """
+
     message = dataframe["dcp_message"]
     message_timestamp = dataframe["message_timestamp_utc"]
     channel = "wl"
@@ -164,7 +155,8 @@ def _twdb_assemble_dataframe(message_timestamp, channel, channel_data, reverse=F
         df.index = pd.to_datetime(df["timestamp_utc"])
         del df["timestamp_utc"]
         return df
-    return pd.DataFrame()
+    else:
+        return pd.DataFrame()
 
 
 def _twdb_stevens_or_dot(df_row, reverse, dual_well=False, drop_dcp_metadata=True):
@@ -232,11 +224,7 @@ def _twdb_stevens_or_dot(df_row, reverse, dual_well=False, drop_dcp_metadata=Tru
                     message_timestamp, channel, channel_data, reverse=reverse
                 )
             except Exception as e:
-                print(
-                    "Warning: Could not parse values for channel {}: {}".format(
-                        field[:2], e
-                    )
-                )
+                print(f"Warning: Could not parse values for channel {field[:2]}: {e}")
         elif "time" in field:
             try:
                 channel, channel_data = field.split(":")
@@ -246,9 +234,7 @@ def _twdb_stevens_or_dot(df_row, reverse, dual_well=False, drop_dcp_metadata=Tru
                 )
             except Exception as e:
                 print(
-                    "Warning: Could not parse values for channel {}: {}".format(
-                        field.split(":")[0], e
-                    )
+                    f"Warning: Could not parse values for channel {field.split(':')[0]}: {e}"
                 )
         elif "channel" in field:
             try:
@@ -257,9 +243,7 @@ def _twdb_stevens_or_dot(df_row, reverse, dual_well=False, drop_dcp_metadata=Tru
                     water_data[channel_name] = []
             except Exception as e:
                 print(
-                    "Warning: Could not parse values for channel {}: {}".format(
-                        field.split(":")[1], e
-                    )
+                    f"Warning: Could not parse values for channel {field.split(':')[1]}: {e}"
                 )
         else:
             try:
@@ -292,7 +276,8 @@ def _parse_value(water_level_str):
             val = well_val[1].strip("-")
         value_dict = (well_val[0], val)
         return value_dict
-    return water_level_str
+    else:
+        return water_level_str
 
 
 def _invalid_message_check(message):
