@@ -1,13 +1,12 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.twc.kbdi.core
-    ~~~~~~~~~~~~~~~~~~~~~
+ulmo.twc.kbdi.core
+~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides direct access to `Texas Weather Connection`_ `Daily
-    Keetch-Byram Drought Index (KBDI)`_ dataset.
+This module provides direct access to `Texas Weather Connection`_ `Daily
+Keetch-Byram Drought Index (KBDI)`_ dataset.
 
-    .. _Texas Weather Connection: http://twc.tamu.edu/
-    .. _Daily Keetch-Byram Drought Index (KBDI): http://twc.tamu.edu/drought/kbdi
+.. _Texas Weather Connection: http://twc.tamu.edu/
+.. _Daily Keetch-Byram Drought Index (KBDI): http://twc.tamu.edu/drought/kbdi
 """
 
 import datetime
@@ -16,7 +15,7 @@ import os
 import numpy as np
 import pandas
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 CSV_SWITCHOVER = pandas.Timestamp("2016-10-01")
 
@@ -47,16 +46,14 @@ def get_data(county=None, start=None, end=None, as_dataframe=False, data_dir=Non
         will be used (the directory will depend on the platform/operating
         system).
 
+
     Returns
     -------
     data : dict or pandas.Dataframe
         A dict or pandas.DataFrame representing the data. See the
         ``as_dataframe`` parameter for more.
     """
-    if end is None:
-        end_date = datetime.date.today()
-    else:
-        end_date = util.convert_date(end)
+    end_date = datetime.date.today() if end is None else util.convert_date(end)
     if start is None:
         start_date = datetime.date(end_date.year, 1, 1)
     else:
@@ -78,9 +75,7 @@ def get_data(county=None, start=None, end=None, as_dataframe=False, data_dir=Non
     if county:
         df = df[df["fips"] == county]
 
-    if as_dataframe:
-        return df
-    return _as_data_dict(df)
+    return df if as_dataframe else _as_data_dict(df)
 
 
 def _as_data_dict(df):
@@ -89,14 +84,13 @@ def _as_data_dict(df):
     for county in df["fips"].unique():
         county_df = df[df["fips"] == county]
         county_data = county_df.T.drop(["fips"])
-        values = [v.to_dict() for k, v in county_data.iteritems()]
+        values = [v.to_dict() for k, v in county_data.items()]
         county_dict[county] = values
 
     return county_dict
 
 
 def _date_dataframe(date, data_dir):
-
     if date.to_timestamp() < CSV_SWITCHOVER:
         url = _get_text_url(date)
         with _open_data_file(url, data_dir) as data_file:
@@ -379,15 +373,11 @@ def _fips_dataframe():
 
 
 def _get_text_url(date):
-    return "https://twc.tamu.edu/weather_images/summ/summ%s.txt" % date.strftime(
-        "%Y%m%d"
-    )
+    return f"http://twc.tamu.edu/weather_images/summ/summ{date.strftime('%Y%m%d')}.txt"
 
 
 def _get_csv_url(date):
-    return "https://twc.tamu.edu/weather_images/summ/summ%s.csv" % date.strftime(
-        "%Y%m%d"
-    )
+    return f"http://twc.tamu.edu/weather_images/summ/summ{date.strftime('%Y%m%d')}.csv"
 
 
 def _parse_text_file(data_file):
@@ -399,6 +389,7 @@ def _parse_text_file(data_file):
                 ANDREWS                          485       614       357
                 ...
     """
+
     dtype = [
         ("county", "|U15"),
         ("avg", "i4"),
@@ -418,8 +409,7 @@ def _parse_text_file(data_file):
         skip_footer=1,
         autostrip=True,
     )
-    dataframe = pandas.DataFrame(data_array)
-    return dataframe
+    return pandas.DataFrame(data_array)
 
 
 def _parse_csv_file(data_file):
@@ -429,6 +419,7 @@ def _parse_csv_file(data_file):
         Anderson,429,684,559,+5
         Andrews,92,356,168,+7
     """
+
     if not data_file.readline().lower().startswith(b"county"):
         return pandas.DataFrame()
     data_file.seek(0)
