@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
+__all__ = ["get_station_data", "get_station_parameters", "get_stations"]
 
 from .core import get_station_data, get_station_parameters, get_stations
