@@ -1,36 +1,33 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.usace.swtwc.core
-    ~~~~~~~~~~~~~~~~~~~~~
+ulmo.usace.swtwc.core
+~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides access to data provided by the `United States Army
-    Corps of Engineers`_ `Tulsa District Water Control`_ web site.
+This module provides access to data provided by the `United States Army
+Corps of Engineers`_ `Tulsa District Water Control`_ web site.
 
-    .. _United States Army Corps of Engineers: http://www.usace.army.mil/
-    .. _Tulsa District Water Control: http://www.swt-wc.usace.army.mil/
+.. _United States Army Corps of Engineers: http://www.usace.army.mil/
+.. _Tulsa District Water Control: http://www.swt-wc.usace.army.mil/
 
 """
 
 import datetime
 import os.path
+from io import StringIO
 
 import numpy as np
 import pandas
 import requests
 from bs4 import BeautifulSoup
 
-from tsgettoolbox.ulmo import util
-
-try:
-    import io as StringIO
-except ImportError:
-    from cStringIO import StringIO
+from ... import util
 
 USACE_SWTWC_DIR = os.path.join(util.get_ulmo_dir(), "usace/swtwc")
 
 
 def get_station_data(station_code, date=None, as_dataframe=False):
-    """Fetches data for a station at a given date.
+    """
+    Fetches data for a station at a given date.
+
 
     Parameters
     ----------
@@ -47,12 +44,13 @@ def get_station_data(station_code, date=None, as_dataframe=False):
         dict will be a pandas.DataFrame object containing the equivalent
         information.
 
+
     Returns
     -------
     data_dict : dict
         A dict containing station information and values.
     """
-    station_dict = {}
+
     if date is None:
         date_str = "current"
         year = datetime.date.today().year
@@ -61,31 +59,25 @@ def get_station_data(station_code, date=None, as_dataframe=False):
         date_str = date.strftime("%Y%m%d")
         year = date.year
 
-    filename = "{}.{}.html".format(station_code, date_str)
-    data_url = "http://www.swt-wc.usace.army.mil/webdata/gagedata/" + filename
+    filename = f"{station_code}.{date_str}.html"
+    data_url = f"https://www.swt-wc.usace.army.mil/webdata/gagedata/{filename}"
 
     # requests without User-Agent header get rejected
     headers = {
         "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36"
     }
-    resp = requests.get(data_url, headers=headers)
-    soup = BeautifulSoup(resp.content, features="lxml")
+    resp = requests.get(data_url, headers=headers, timeout=60)
+    soup = BeautifulSoup(resp.content)
     pre = soup.find("pre")
     if pre is None:
-        error_msg = "no data could be found for station code {station_code} and date {date} (url: {data_url})".format(
-            date=date,
-            data_url=data_url,
-            station_code=station_code,
-        )
+        error_msg = f"no data could be found for station code {station_code} and date {date} (url: {data_url})"
         raise ValueError(error_msg)
-    sio = StringIO.StringIO(str(pre.text.strip()))
+    sio = StringIO(str(pre.text.strip()))
 
     first_line = sio.readline()
     split = first_line[8:].strip().split()
 
-    station_dict["code"] = split[0]
-    station_dict["description"] = " ".join(split[1:])
-
+    station_dict = {"code": split[0], "description": " ".join(split[1:])}
     second_line = sio.readline()
     station_dict["station_type"] = second_line.strip().split(":")[1].strip()
 
@@ -117,7 +109,10 @@ def get_station_data(station_code, date=None, as_dataframe=False):
         variable_name: lambda x: float(x) if x != "----" else np.nan
         for variable_name in variable_names
     }
-    date_parser = lambda x: _convert_datetime(x, year)
+
+    def date_parser(x):
+        _convert_datetime(x, year)
+
     dataframe = pandas.read_fwf(
         sio,
         names=column_names,
@@ -148,12 +143,12 @@ def get_stations():
     stations_dict : dict
         a python dict with station codes mapped to station information
     """
-    stations_url = "http://www.swt-wc.usace.army.mil/shefids.htm"
+    stations_url = "https://www.swt-wc.usace.army.mil/shefids.htm"
 
     headers = {
         "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36"
     }
-    resp = requests.get(stations_url, headers=headers)
+    resp = requests.get(stations_url, headers=headers, timeout=60)
     soup = BeautifulSoup(resp.content)
     pre = soup.find("pre")
     links = pre.find_all("a")
