@@ -1,17 +1,15 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.usgs.ned.core
-    ~~~~~~~~~~~~~~~~~~~~~
+ulmo.usgs.ned.core
+~~~~~~~~~~~~~~~~~~~~~
 
-    This module provides access to the `National Elevation Dataset` provided by the `United States Geological
-    Survey`_ `National Map`_ system.
+This module provides access to the `National Elevation Dataset` provided by the `United States Geological
+Survey`_ `National Map`_ system.
 
-    .. _National Elevation Dataset: http://ned.usgs.gov/
-    .. _United States Geological Survey: http://www.usgs.gov/
-    .. _National Map: http://nationalmap.gov
+.. _National Elevation Dataset: http://ned.usgs.gov/
+.. _United States Geological Survey: http://www.usgs.gov/
+.. _National Map: http://nationalmap.gov
 
 """
-from __future__ import print_function
 
 import logging
 import os
@@ -19,7 +17,7 @@ import os
 import requests
 from geojson import Feature, FeatureCollection, Polygon
 
-from tsgettoolbox.ulmo import util
+from ... import util
 
 # NED ftp url.
 NED_FTP_URL = "ftp://rockyftp.cr.usgs.gov/vdelivery/Datasets/Staged/NED/<layer>/IMG/"
@@ -63,6 +61,7 @@ def get_raster_availability(layer, bbox=None):
     metadata : geojson FeatureCollection
         returns metadata including download urls as a FeatureCollection
     """
+
     base_url = "https://www.sciencebase.gov/catalog/items"
     params = [
         ("parentId", layer_dict[layer]),
@@ -73,33 +72,20 @@ def get_raster_availability(layer, bbox=None):
     ]
 
     if bbox:
-        xmin, ymin, xmax, ymax = [float(n) for n in bbox]
-        polygon = "POLYGON (({}))".format(
-            ",".join(
-                [
-                    (repr(x) + " " + repr(y))
-                    for x, y in [
-                        (xmin, ymax),
-                        (xmin, ymin),
-                        (xmax, ymin),
-                        (xmax, ymax),
-                        (xmin, ymax),
-                    ]
-                ]
-            )
-        )
+        xmin, ymin, xmax, ymax = (float(n) for n in bbox)
+        polygon = f"POLYGON (({','.join([f'{repr(x)} {repr(y)}' for x, y in [(xmin, ymax), (xmin, ymin), (xmax, ymin), (xmax, ymax), (xmin, ymax)]])}))"
         params.append(
             (
                 "filter",
-                'spatialQuery={{wkt:"{}",relation:"{}"}}'.format(polygon, "intersects"),
+                f'spatialQuery={{wkt:"{polygon}",relation:"intersects"}}',
             )
         )
 
     features = []
     url = base_url
     while url:
-        r = requests.get(url, params)
-        print("retrieving raster availability from %s" % r.url)
+        r = requests.get(url, params, timeout=30)
+        print(f"retrieving raster availability from {r.url}")
         params = []  # not needed after first request
         content = r.json()
         for item in content["items"]:
@@ -164,9 +150,9 @@ def get_raster(
             path = os.path.join(util.get_ulmo_dir(), DEFAULT_FILE_PATH)
 
         util.mkdir_if_doesnt_exist(os.path.join(path, "by_boundingbox"))
-        xmin, ymin, xmax, ymax = [float(n) for n in bbox]
+        xmin, ymin, xmax, ymax = (float(n) for n in bbox)
         uid = util.generate_raster_uid(layer, xmin, ymin, xmax, ymax)
-        output_path = os.path.join(path, "by_boundingbox", uid + ".tif")
+        output_path = os.path.join(path, "by_boundingbox", f"{uid}.tif")
 
         if os.path.isfile(output_path) and not update_cache:
             return output_path
@@ -182,8 +168,9 @@ def _check_layer(layer):
     """
     make sure the passed layer name is one of the handled options
     """
-    if not layer in get_available_layers():
-        err_msg = "The specified layer parameter ({})".format(layer)
+
+    if layer not in get_available_layers():
+        err_msg = f"The specified layer parameter ({layer})"
         err_msg += "\nis not in the available options:"
         err_msg += "\n\t".join(get_available_layers())
         raise ValueError(err_msg)
@@ -203,8 +190,11 @@ def _download_features(
     tiles = []
     tile_fmt = ".img"
     for feature_id in feature_ids:
-        url = SCIENCEBASE_ITEM_URL % feature_id
-        metadata = requests.get(url).json()
+        url = (
+            "https://www.sciencebase.gov/catalogMaps/mapping/ows/{0}?service=wcs&request=getcapabilities&version=1.0.0"
+            % feature_id
+        )
+        metadata = requests.get(url, timeout=60).json()
         layer = [a for a in list(layer_dict.keys()) if a in metadata["title"]][0]
         layer_path = os.path.join(path, layer_dict[layer])
         tile_urls = [
@@ -232,12 +222,10 @@ def _bbox2poly(bbox):
 
 
 def _download_tiles(tiles, path=None, check_modified=False):
-
     if path is None:
         path = os.path.join(util.get_ulmo_dir(), DEFAULT_FILE_PATH)
 
     for tile in tiles["features"]:
-
         metadata = tile["properties"]
         layer_path = os.path.join(path, layer_dict[metadata["layer"]])
         tile["properties"]["file"] = util.download_tiles(
