@@ -1,14 +1,19 @@
-# -*- coding: utf-8 -*-
 """
-    `USGS National Water Information System`_ web services
+`USGS National Water Information System`_ web services
 
 
-    .. _USGS National Water Information System: http://waterdata.usgs.gov/nwis
+.. _USGS National Water Information System: http://waterdata.usgs.gov/nwis
 """
-from __future__ import absolute_import
 
-from tsgettoolbox.ulmo import util
+__all__ = [
+    "core",
+    "get_site_data",
+    "get_sites",
+    "hdf5",
+    "pytables",
+]
 
+from ... import util
 from . import core
 from .core import get_site_data, get_sites
 
