@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 """
-    ulmo.usgs.core
-    ~~~~~~~~~~~~~~
+ulmo.usgs.core
+~~~~~~~~~~~~~~
 
-    This module provides direct access to `USGS National Water Information
-    System`_ web services.
+This module provides direct access to `USGS National Water Information
+System`_ web services.
 
-    .. _USGS National Water Information System: http://waterdata.usgs.gov/nwis
+.. _USGS National Water Information System: http://waterdata.usgs.gov/nwis
 
 """
 
@@ -18,11 +17,11 @@ import logging
 import isodate
 import requests
 
-from tsgettoolbox.ulmo import util
-from tsgettoolbox.ulmo.waterml import v1_1 as wml
+from ... import util
+from ...waterml import v1_1 as wml
 
-INSTANTANEOUS_URL = "http://waterservices.usgs.gov/nwis/iv/"
-DAILY_URL = "http://waterservices.usgs.gov/nwis/dv/"
+INSTANTANEOUS_URL = "https://waterservices.usgs.gov/nwis/iv/"
+DAILY_URL = "https://waterservices.usgs.gov/nwis/dv/"
 
 # configure logging
 LOG_FORMAT = "%(message)s"
@@ -41,9 +40,11 @@ def get_sites(
     county_code=None,
     parameter_code=None,
     site_type=None,
-    **kwargs
+    **kwargs,
 ):
-    """Fetches site information from USGS services.
+    """
+    Fetches site information from USGS services.
+
     See the `USGS Site Service`_ documentation for a detailed description of options.
     For convenience, major options have been included with pythonic names.
     At least one major filter must be specified. Options that are not listed
@@ -102,6 +103,7 @@ def get_sites(
     return_sites : dict
         a python dict with site codes mapped to site information
     """
+
     if input_file is None:
         # Checking to see if the correct amount of major filters are being used.
         # The NWIS site requires only one major filter to be used at a time.
@@ -159,15 +161,15 @@ def get_sites(
                     site_type=site_type,
                     service=service,
                     input_file=input_file,
-                    **kwargs
+                    **kwargs,
                 )
                 return_sites.update(new_sites)
             return return_sites
 
         url = _get_service_url(service)
-        log.info("making request for sites: %s" % url)
-        req = requests.get(url, params=url_params)
-        log.info("processing data from request: %s" % req.request.url)
+        log.info(f"making request for sites: {url}")
+        req = requests.get(url, params=url_params, timeout=60)
+        log.info(f"processing data from request: {req.request.url}")
         req.raise_for_status()
         input_file = io.BytesIO(util.to_bytes(req.content))
 
@@ -192,7 +194,7 @@ def get_site_data(
     modified_since=None,
     input_file=None,
     methods=None,
-    **kwargs
+    **kwargs,
 ):
     """Fetches site data.
 
@@ -243,18 +245,18 @@ def get_site_data(
         a python dict with parameter codes mapped to value dicts
     """
     url_params = {"format": "waterml", "site": site_code}
-    if type(parameter_code) is str:
+    if isinstance(parameter_code, str):
         url_params["parameterCd"] = parameter_code
-    elif type(parameter_code) is list:
+    elif isinstance(parameter_code, list):
         url_params["parameterCd"] = ",".join(parameter_code)
     if statistic_code:
         url_params["statCd"] = statistic_code
     if modified_since:
         url_params["modifiedSince"] = isodate.duration_isoformat(modified_since)
 
-    if not (start is None or end is None) and period is not None:
+    if start is not None and end is not None and period is not None:
         raise ValueError(
-            "must use either a date range with start/end OR a " "period, but not both"
+            "must use either a date range with start/end OR a period, but not both"
         )
     if period is not None:
         if isinstance(period, str):
@@ -304,9 +306,7 @@ def get_site_data(
 
 def _as_str(arg):
     """if arg is a list, convert to comma delimited string"""
-    if isinstance(arg, str):
-        return arg
-    return ",".join(arg)
+    return arg if isinstance(arg, str) else ",".join(arg)
 
 
 def _extract_site_properties(site):
@@ -333,11 +333,12 @@ def _extract_site_properties(site):
 def _get_service_url(service):
     if service in ("daily", "dv"):
         return DAILY_URL
-    if service in ("instantaneous", "iv"):
+    elif service in ("instantaneous", "iv"):
         return INSTANTANEOUS_URL
-    raise ValueError(
-        "service must be either 'daily' ('dv') or " "'instantaneous' ('iv')"
-    )
+    else:
+        raise ValueError(
+            "service must be either 'daily' ('dv') or 'instantaneous' ('iv')"
+        )
 
 
 def _get_site_values(service, url_params, input_file=None, methods=None):
@@ -350,14 +351,13 @@ def _get_site_values(service, url_params, input_file=None, methods=None):
         service_url = _get_service_url(service)
 
         try:
-            req = requests.get(service_url, params=url_params)
+            req = requests.get(service_url, params=url_params, timeout=60)
         except requests.exceptions.ConnectionError:
             log.info(
-                "There was a connection error with query:\n\t%s\n\t%s"
-                % (service_url, url_params)
+                f"There was a connection error with query:\n\t{service_url}\n\t{url_params}"
             )
             return {}
-        log.info("processing data from request: %s" % req.request.url)
+        log.info(f"processing data from request: {req.request.url}")
 
         if req.status_code != 200:
             return {}
