@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import contextlib
 import copy
 import os
@@ -12,8 +11,8 @@ import pandas
 import tables
 from tables.scripts import ptrepack
 
-from tsgettoolbox.ulmo import util
-from tsgettoolbox.ulmo.usgs.nwis import core
+from ... import util
+from . import core
 
 # default hdf5 file path
 DEFAULT_HDF5_FILE_PATH = util.get_default_h5file_path("usgs/")
@@ -76,8 +75,7 @@ def get_sites(path=None, complevel=None, complib=None):
             return {}
 
         sites_df = store[SITES_TABLE]
-    sites_dict = _sites_df_to_dict(sites_df)
-    return sites_dict
+    return _sites_df_to_dict(sites_df)
 
 
 def get_site(site_code, path=None, complevel=None, complib=None):
@@ -114,8 +112,8 @@ def get_site(site_code, path=None, complevel=None, complib=None):
     sites = get_sites(path=sites_store_path, complevel=complevel, complib=complib)
     try:
         return sites[site_code]
-    except KeyError:
-        raise LookupError("could not find site: %s" % site_code)
+    except KeyError as e:
+        raise LookupError(f"could not find site: {site_code}") from e
 
 
 def get_site_data(
@@ -215,9 +213,7 @@ def remove_values(
         site_group = store.get_node(site_code)
         if site_group is None:
             core.log.warning(
-                "No site group found for site {} in {}".format(
-                    site_code, site_data_path
-                )
+                f"No site group found for site {site_code} in {site_data_path}"
             )
             return
 
@@ -233,31 +229,26 @@ def remove_values(
                 datetimes_to_remove = original_datetimes.intersection(set(datetimes))
                 if not datetimes_to_remove:
                     core.log.info(
-                        "No %s values matching the given datetimes to remove were found."
-                        % variable_code
+                        f"No {variable_code} values matching the given datetimes to remove were found."
                     )
                     continue
                 else:
-                    values_df.loc[list(datetimes_to_remove), "value"] = np.nan
+                    values_df.ix[list(datetimes_to_remove), "value"] = np.nan
                     core.log.info(
-                        "%i %s values were set to NaNs in file"
-                        % (len(datetimes_to_remove), variable_code)
+                        f"{len(datetimes_to_remove)} {variable_code} values were set to NaNs in file"
                     )
 
             else:
                 core.log.warning(
-                    "Values path {} not found in {}.".format(
-                        values_path, site_data_path
-                    )
+                    f"Values path {values_path} not found in {site_data_path}."
                 )
                 continue
 
             store[values_path] = values_df
             something_changed = True
 
-    if autorepack:
-        if something_changed:
-            repack(site_data_path, complevel=complevel, complib=complib)
+    if autorepack and something_changed:
+        repack(site_data_path, complevel=complevel, complib=complib)
 
 
 def repack(path, complevel=None, complib=None):
@@ -304,7 +295,7 @@ def update_site_list(
     complib=None,
     autorepack=True,
     path=None,
-    **kwargs
+    **kwargs,
 ):
     """Update cached site information.
 
@@ -355,7 +346,7 @@ def update_site_list(
         site_type=site_type,
         service=service,
         input_file=input_file,
-        **kwargs
+        **kwargs,
     )
 
     if len(new_sites) == 0:
@@ -423,6 +414,7 @@ def update_site_data(
         become quite destructive.  If you set this to False, you can manually
         repack files with repack().
 
+
     Returns
     -------
     None : ``None``
@@ -514,13 +506,10 @@ def _compression_kwargs(complevel=None, complib=None):
     if complib is None and complevel is None:
         possible_compressions = ("blosc", "zlib")
         for possible_compression in possible_compressions:
-            try:
+            with contextlib.suppress(tables.FiltersWarning):
                 try_kwargs = dict(complevel=9, complib=possible_compression)
                 tables.Filters(**try_kwargs)
                 return try_kwargs
-            except tables.FiltersWarning:
-                pass
-
         complevel = 0
 
     elif complib is not None and complevel is None:
@@ -547,7 +536,7 @@ def _get_last_refresh(site_code, path, complevel=None, complib=None):
             if pandas.isnull(last_refresh):
                 last_refresh = None
             return last_refresh
-    except IOError:
+    except OSError:
         return None
 
 
@@ -568,7 +557,8 @@ def _get_store_path(path, default_file_name):
         path = DEFAULT_HDF5_FILE_PATH
     if isinstance(path, str) and (path.endswith("/") or path.endswith("\\")):
         return os.path.join(path, default_file_name)
-    return path
+    else:
+        return path
 
 
 def _nans_to_none(df):
@@ -593,7 +583,9 @@ def _nest_dataframe_dicts(unnested_df, nested_column, keys):
 
 def _ptrepack(src, dst, complevel, complib):
     """run ptrepack to repack from src to dst"""
+
     # check_output(['ptrepack','--complevel=%s' % complevel, '--complib=%s' % complib, src, dst])
+
     # fix for for pytables not finding files on windows because of drive in path
     src = os.path.splitdrive(src)[-1]
     dst = os.path.splitdrive(dst)[-1]
@@ -601,8 +593,8 @@ def _ptrepack(src, dst, complevel, complib):
     with _sysargs_hacks():
         sys.argv = [
             "",
-            "--complevel=%s" % complevel,
-            "--complib=%s" % complib,
+            f"--complevel={complevel}",
+            f"--complib={complib}",
             src,
             dst,
         ]
