@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import datetime
 import email.utils
 import ftplib
@@ -10,12 +8,13 @@ import urllib.parse
 import warnings
 from contextlib import contextmanager
 
-import appdirs
 import numpy as np
 import pandas
 import requests
 from lxml import etree
 
+from ... import appdirs
+
 # pre-compiled regexes for underscore conversion
 first_cap_re = re.compile("(.)([A-Z][a-z]+)")
 all_cap_re = re.compile("([a-z0-9])([A-Z])")
@@ -63,20 +62,14 @@ def dict_from_dataframe(dataframe):
     if isinstance(dataframe.index, pandas.DatetimeIndex):
         dataframe.index = [str(i) for i in dataframe.index]
 
-    # convert np.nan objects to None objects; prior to pandas 0.13.0 this could
-    # be done in a vectorized way, but as of 0.13, assigning None into a
-    # dataframe, it gets converted to a nan object so this has to be done
-    # rather inefficiently in a post-processing step
-    if pandas.__version__ < "0.13.0":
-        for column_name in dataframe.columns:
-            dataframe[column_name][pandas.isnull(dataframe[column_name])] = None
-        df_dict = dataframe.T.to_dict()
-    else:
-        df_dict = dataframe.where((pandas.notnull(dataframe)), None).to_dict(
+    if pandas.__version__ >= "0.13.0":
+        return dataframe.where((pandas.notnull(dataframe)), None).to_dict(
             orient="index"
         )
 
-    return df_dict
+    for column_name in dataframe.columns:
+        dataframe[column_name][pandas.isnull(dataframe[column_name])] = None
+    return dataframe.T.to_dict()
 
 
 def download_if_new(url, path, check_modified=True):
@@ -112,7 +105,7 @@ def mkdir_if_doesnt_exist(dir_path):
 
 
 def module_with_dependency_errors(method_names):
-    class FakeModule(object):
+    class FakeModule:
         pass
 
     fake_module = FakeModule()
@@ -130,7 +123,7 @@ def module_with_dependency_errors(method_names):
 def module_with_deprecation_warnings(functions, warning_message):
     warnings.filterwarnings("always", warning_message, DeprecationWarning)
 
-    class DeprecatedModule(object):
+    class DeprecatedModule:
         pass
 
     deprecated_module = DeprecatedModule()
@@ -160,18 +153,17 @@ def open_file_for_url(url, path, check_modified=True, use_file=None, use_bytes=N
     """
     leave_open = False
 
-    if use_file is not None:
-        if hasattr(use_file, "read"):
-            leave_open = True
-            yield use_file
-        else:
-            open_path = use_file
-    else:
+    if use_file is None:
         download_if_new(url, path, check_modified)
         open_path = path
 
+    elif hasattr(use_file, "read"):
+        leave_open = True
+        yield use_file
+    else:
+        open_path = use_file
     if use_bytes is None:
-        open_file = open(open_path, "r")
+        open_file = open(open_path)
     else:
         open_file = open(open_path, "rb")
 
@@ -226,10 +218,8 @@ def save_pretty_printed_xml(filename, response_buffer):
 
 def to_bytes(s):
     """convert str to bytes for py 2/3 compat"""
-    if isinstance(s, bytes):
-        return s
 
-    return s.encode("utf-8", "ignore")
+    return s if isinstance(s, bytes) else s.encode("utf-8", "ignore")
 
 
 def _ftp_download_if_new(url, path, check_modified=True):
@@ -247,7 +237,7 @@ def _ftp_download_if_new(url, path, check_modified=True):
 
 def _ftp_download_file(ftp, ftp_path, local_path):
     with open(local_path, "wb") as f:
-        ftp.retrbinary("RETR " + ftp_path, f.write)
+        ftp.retrbinary(f"RETR {ftp_path}", f.write)
 
 
 def _ftp_file_size(ftp, file_path):
@@ -256,12 +246,12 @@ def _ftp_file_size(ftp, file_path):
 
 
 def _ftp_last_modified(ftp, file_path):
-    timestamp = ftp.sendcmd("MDTM " + file_path).split()[-1]
+    timestamp = ftp.sendcmd(f"MDTM {file_path}").split()[-1]
     return datetime.datetime.strptime(timestamp, "%Y%m%d%H%M%S")
 
 
 def _http_download_file(url, path):
-    request = requests.get(url, verify=False)
+    request = requests.get(url, timeout=60)
     mkdir_if_doesnt_exist(os.path.dirname(path))
     chunk_size = 64 * 1024
     with open(path, "wb") as f:
@@ -270,7 +260,7 @@ def _http_download_file(url, path):
 
 
 def _http_download_if_new(url, path, check_modified):
-    head = requests.head(url, verify=False)
+    head = requests.head(url, timeout=60, verify=False)
     if not os.path.exists(path) or not _request_file_size_matches(head, path):
         _http_download_file(url, path)
     elif check_modified and _request_is_newer_than_file(head, path):
@@ -300,9 +290,7 @@ def _path_last_modified(path):
 def _request_file_size_matches(request, path):
     """returns True if request content-length header matches file size"""
     content_length = request.headers.get("content-length")
-    if content_length and int(content_length) == os.path.getsize(path):
-        return True
-    return False
+    return bool(content_length and int(content_length) == os.path.getsize(path))
 
 
 def _request_is_newer_than_file(request, path):
@@ -316,14 +304,11 @@ def _request_is_newer_than_file(request, path):
 
     if not request.headers.get("last-modified"):
         warnings.warn(
-            "no last-modified date for request: %s, downloading file again"
-            % request.url
+            f"no last-modified date for request: {request.url}, downloading file again"
         )
         return True
 
     request_last_modified = _parse_rfc_1123_timestamp(
         request.headers.get("last-modified")
     )
-    if request_last_modified > path_last_modified:
-        return True
-    return False
+    return request_last_modified > path_last_modified
