@@ -1,2 +1,3 @@
-# -*- coding: utf-8 -*-
+__all__ = ["v1_0", "v1_1"]
+
 from . import v1_0, v1_1
