@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 import isodate
 from lxml import etree
 
-from tsgettoolbox.ulmo import util
+from .. import util
 
 
 def parse_site_values(content_io, namespace, query_isodate=None, methods=None):
@@ -18,13 +17,13 @@ def parse_site_values(content_io, namespace, query_isodate=None, methods=None):
         ("qualityControlLevel", "quality_control_levels", "id"),
         ("source", "sources", "id"),
     ]
-    for (event, ele) in etree.iterparse(content_io):
-        if ele.tag == namespace + "timeSeries":
-            source_info_element = ele.find(namespace + "sourceInfo")
+    for event, ele in etree.iterparse(content_io):
+        if ele.tag == f"{namespace}timeSeries":
+            source_info_element = ele.find(f"{namespace}sourceInfo")
             site_info = _parse_site_info(source_info_element, namespace)
-            var_element = ele.find(namespace + "variable")
+            var_element = ele.find(f"{namespace}variable")
             variable = _parse_variable(var_element, namespace)
-            values_elements = ele.findall(namespace + "values")
+            values_elements = ele.findall(f"{namespace}values")
             code = variable["code"]
             if isinstance(methods, str):
                 method = methods
@@ -33,13 +32,12 @@ def parse_site_values(content_io, namespace, query_isodate=None, methods=None):
             else:
                 method = None
             if "statistic" in variable:
-                code += ":" + variable["statistic"]["code"]
+                code += f":{variable['statistic']['code']}"
 
             if method is None:
                 if len(values_elements) > 1:
                     raise ValueError(
-                        "found more than one method for %s. need to specify"
-                        'specify code or "all".' % variable["code"]
+                        f'found more than one method for {variable["code"]}. need to specifyspecify code or "all".'
                     )
                 values_element = values_elements[0]
                 values = _parse_values(values_element, namespace)
@@ -58,14 +56,11 @@ def parse_site_values(content_io, namespace, query_isodate=None, methods=None):
                     metadata = _parse_metadata(
                         values_element, metadata_elements, namespace
                     )
-                    if len(values_elements) > 1:
-                        updated_code = (
-                            code
-                            + ":"
-                            + str(list(metadata["methods"].values())[0]["id"])
-                        )
-                    else:
-                        updated_code = code
+                    updated_code = (
+                        f"{code}:" + str(list(metadata["methods"].values())[0]["id"])
+                        if len(values_elements) > 1
+                        else code
+                    )
                     data_dict[updated_code] = {
                         "site": site_info.copy(),
                         "variable": variable,
@@ -77,9 +72,7 @@ def parse_site_values(content_io, namespace, query_isodate=None, methods=None):
             else:
                 for values_element in values_elements:
                     if (
-                        values_element.find(
-                            namespace + 'method[@methodID="%s"]' % method
-                        )
+                        values_element.find(f'{namespace}method[@methodID="{method}"]')
                         is not None
                     ):
                         values = _parse_values(values_element, namespace)
@@ -174,7 +167,7 @@ def _element_dict(element, exclude_children=None, prepend_attributes=True):
     element_dict = {}
     element_name = util.camel_to_underscore(element.tag.split("}")[-1])
 
-    if len(element) == 0 and not element.text is None:
+    if len(element) == 0 and element.text is not None:
         element_dict[element_name] = element.text
 
     element_dict.update(
@@ -188,7 +181,7 @@ def _element_dict(element, exclude_children=None, prepend_attributes=True):
     )
 
     for child in element.iterchildren():
-        if not child.tag.split("}")[-1] in exclude_children:
+        if child.tag.split("}")[-1] not in exclude_children:
             element_dict.update(_element_dict(child))
 
     return element_dict
@@ -200,7 +193,8 @@ def _element_dict_attribute_name(
     attribute_only = util.camel_to_underscore(attribute_name.split("}")[-1])
     if attribute_only.startswith(element_name) or not prepend_element_name:
         return attribute_only
-    return element_name + "_" + attribute_only
+    else:
+        return element_name + "_" + attribute_only
 
 
 def _find_unit(element, namespace):
@@ -229,7 +223,7 @@ def _parse_geog_location(geog_location, namespace):
     }
 
     srs = geog_location.attrib.get("srs")
-    if not srs is None:
+    if srs is not None:
         return_dict["srs"] = srs
 
     return return_dict
@@ -243,7 +237,7 @@ def _parse_metadata(values_element, metadata_elements, namespace):
             _scrub_prefix(_element_dict(element, namespace), underscored_tag)
             for element in values_element.findall(namespace + tag)
         ]
-        if [x for x in collection if len(x)]:
+        if len([x for x in collection if len(x)]):
             collection_dict = {item[key]: item for item in collection if key in item}
             metadata[collection_name] = collection_dict
     return metadata
@@ -271,7 +265,7 @@ def _parse_series(series, namespace):
 
     for include_element in include_elements:
         element = series.find(namespace + include_element)
-        if not element is None:
+        if element is not None:
             name = util.camel_to_underscore(element.tag)
             element_dict = _scrub_prefix(_element_dict(element), name)
             series_dict[name] = element_dict
@@ -309,15 +303,15 @@ def _parse_site_info(site_info, namespace):
         return_dict["agency"] = agency
 
     geog_location = site_info.find(namespace.join(["", "geoLocation/", "geogLocation"]))
-    if not geog_location is None:
+    if geog_location is not None:
         return_dict["location"] = _parse_geog_location(geog_location, namespace)
 
     timezone_info = site_info.find(namespace + "timeZoneInfo")
-    if not timezone_info is None:
+    if timezone_info is not None:
         return_dict["timezone_info"] = _parse_timezone_info(timezone_info, namespace)
 
     elevation_m = site_info.find(namespace + "elevation_m")
-    if not elevation_m is None:
+    if elevation_m is not None:
         return_dict["elevation_m"] = elevation_m.text
 
     # WaterML 1.0 notes
@@ -362,7 +356,7 @@ def _parse_timezone_info(timezone_info, namespace):
         return_dict["uses_dst"] = False
 
     dst_element = timezone_info.find(namespace + "daylightSavingsTimeZone")
-    if not dst_element is None:
+    if dst_element is not None:
         return_dict["dst_tz"] = _parse_timezone_element(dst_element)
 
     return_dict["default_tz"] = _parse_timezone_element(
@@ -379,7 +373,7 @@ def _parse_time_info(time_info_element, namespace):
     return_dict = {}
 
     is_regular = time_info_element.attrib.get("isRegular")
-    if not is_regular is None:
+    if is_regular is not None:
         if is_regular.lower() == "true":
             is_regular = True
         elif is_regular.lower() == "false":
@@ -392,11 +386,11 @@ def _parse_time_info(time_info_element, namespace):
         interval_tag = "timeSupport"
 
     interval_element = time_info_element.find(namespace + interval_tag)
-    if not interval_element is None:
+    if interval_element is not None:
         return_dict["interval"] = interval_element.text
 
     unit_element = _find_unit(time_info_element, namespace)
-    if not unit_element is None:
+    if unit_element is not None:
         return_dict["units"] = _parse_unit(unit_element, namespace)
 
     return return_dict
@@ -438,6 +432,7 @@ def _parse_values(values_element, namespace):
     """returns a list of dicts that represent the values for a given etree
     values element
     """
+
     return [
         _parse_value(value, namespace)
         for value in values_element.findall(namespace + "value")
@@ -486,15 +481,15 @@ def _parse_variable(variable_element, namespace):
     elif "1.1" in namespace:
         time_info_name = "timeScale"
     time_info_element = variable_element.find(namespace + time_info_name)
-    if not time_info_element is None:
+    if time_info_element is not None:
         return_dict["time"] = _parse_time_info(time_info_element, namespace)
 
     unit_element = _find_unit(variable_element, namespace)
-    if not unit_element is None:
+    if unit_element is not None:
         return_dict["units"] = _parse_unit(unit_element, namespace)
 
-    variable_description = variable_element.find(namespace + "variableDescription")
-    if not variable_description is None:
+    variable_description = variable_element.find(f"{namespace}variableDescription")
+    if variable_description is not None:
         return_dict["description"] = variable_description.text
 
     return return_dict
@@ -502,4 +497,4 @@ def _parse_variable(variable_element, namespace):
 
 def _scrub_prefix(element_dict, prefix):
     "returns a dict with prefix scrubbed from the keys"
-    return {k.split(prefix + "_")[-1]: v for k, v in element_dict.items()}
+    return {k.split(f"{prefix}_")[-1]: v for k, v in element_dict.items()}
