@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-from tsgettoolbox.ulmo.waterml import common
+from . import common
 
 WATERML_V1_0_NAMESPACE = "{http://www.cuahsi.org/waterML/1.0/}"
 
