@@ -1,89 +1,132 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
+"""
+tsgettoolbox utility functions.
+"""
 
+import configparser as cp
+import contextlib
 import datetime
+import getpass
 import io
-import multiprocessing
 import os
+import platform
+import sys
+import textwrap
 import xml
 from multiprocessing import Pool
-from random import randint
-from time import sleep
+from netrc import netrc
+from pathlib import Path
 
 import cftime
 import numpy as np
 import pandas as pd
 import requests
-import typic
 from haversine import haversine_vector
-from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.util.retry import Retry
+from platformdirs import user_config_dir
+from pydap.client import open_url
+from requests.adapters import HTTPAdapter, Retry
 from siphon.ncss import NCSS
 
+from .toolbox_utils.src.toolbox_utils import tsutils
+
 try:
-    import ConfigParser as cp
+    from pydantic import validate_call
 except ImportError:
-    import configparser as cp
+    from pydantic import validate_arguments as validate_call
 
-from pydap.client import open_url
-from tstoolbox import tsutils
+__all__ = []
 
-from . import appdirs
 
-dirs = appdirs.AppDirs("tsgettoolbox", "tsgettoolbox")
+def read_netrc(machine):
+    """Read machine auth from .netrc key if exists else create key."""
+    netrcfile = "_netrc" if platform.system() == "Windows" else ".netrc"
+    netrcpath = Path.home() / netrcfile
+    if not netrcpath.exists():
+        with open(netrcpath, "w", encoding="ascii") as fpnetrc:
+            fpnetrc.write("")
+
+    nrc = netrc(str(netrcpath))
+    auths = nrc.authenticators(machine)
+    if auths is None:
+        if machine == "urs.earthdata.nasa.gov":
+            print(
+                textwrap.dedent(
+                    f"""\
+                    *
+                    * To access NASA Earthdata services you need to create a free
+                    * account at https://urs.earthdata.nasa.gov/users/new
+                    *
+                    * After creating your account you can enter your credentials
+                    * below to have them stored in
+                    * '{netrcpath}'
+                    * file for future use.
+                    *
+                    """
+                ),
+                file=sys.stderr,
+            )
+        username = input(f"Username for '{machine}': ")
+        password = getpass.getpass(f"Password for '{machine}': ")
+        nrc.hosts[machine] = (username, None, password)
+        with open(netrcpath, "w", encoding="ascii") as fpnetrc:
+            fpnetrc.write(repr(nrc))
+        os.chmod(netrcpath, 0o600)
+
+    nrc = netrc(str(netrcpath))
+    auths = nrc.authenticators(machine)
+    return auths[0], auths[2]
 
 
 def read_api_key(service):
-    # Read in API key
-    if not os.path.exists(dirs.user_config_dir):
-        os.makedirs(dirs.user_config_dir)
-    configfile = os.path.join(dirs.user_config_dir, "config.ini")
+    """Read API key from file if exists else create key place holder."""
+    dirs = user_config_dir("tsgettoolbox", "tsgettoolbox")
+    if not os.path.exists(dirs):
+        os.makedirs(dirs)
+    configfile = os.path.join(dirs, "config.ini")
     if not os.path.exists(configfile):
-        with open(configfile, "w") as fp:
-            fp.write(
-                """
+        with open(configfile, "w", encoding="ascii") as fpconfig:
+            fpconfig.write(
+                textwrap.dedent(
+                    f"""\
 
-[{}]
-api_key = ReplaceThisStringWithYourKey
+                    [{service}]
+                    api_key = ReplaceThisStringWithYourKey
 
-""".format(
-                    service
+                    """
                 )
             )
     # Make sure read only by user.
     os.chmod(configfile, 0o600)
 
     inifile = cp.ConfigParser()
-    inifile.readfp(open(configfile, "r"))
+    inifile.read_file(open(configfile, encoding="ascii"))
 
     try:
         api_key = inifile.get(service, "api_key")
-    except BaseException:
-        with open(configfile, "a") as fp:
-            fp.write(
-                """
+    except KeyError:
+        with open(configfile, "a", encoding="ascii") as fpconfig:
+            fpconfig.write(
+                textwrap.dedent(
+                    f"""\
 
-[{}]
-api_key = ReplaceThisStringWithYourKey
+                    [{service}]
+                    api_key = ReplaceThisStringWithYourKey
 
-""".format(
-                    service
+                    """
                 )
             )
         api_key = "ReplaceThisStringWithYourKey"
 
-    inifile.readfp(open(configfile, "r"))
+    inifile.read_file(open(configfile, encoding="ascii"))
     api_key = inifile.get(service, "api_key")
     if api_key == "ReplaceThisStringWithYourKey":
         raise ValueError(
-            """
-*
-*   Need to edit {}
-*   to add your API key that you got from {}.
-*
-""".format(
-                configfile, service
-            )
+            textwrap.dedent(f"""\
+                *
+                * Need to edit '{configfile}'
+                * to add your API key that you got from
+                * '{service}'.
+                *
+                """)
         )
 
     return api_key
@@ -95,6 +138,7 @@ def requests_retry_session(
     status_forcelist=(429, 500, 502, 503, 504),
     session=None,
 ):
+    """Retry requests session."""
     session = session or requests.Session()
     retry = Retry(
         total=retries,
@@ -109,10 +153,8 @@ def requests_retry_session(
     return session
 
 
-import gzip
-
-
 def read_csv(filename):
+    """Read csv file."""
     req = requests_retry_session().get(filename)
     try:
         req.raise_for_status()
@@ -128,20 +170,16 @@ def read_csv(filename):
 
 def file_downloader(baseurl, station, startdate=None, enddate=None):
     """Generic NCEI/NOAA file downloader."""
-    if startdate is None:
-        startdate = datetime.datetime(1901, 1, 1)
-    else:
+    if startdate:
         startdate = pd.to_datetime(startdate)
-    if enddate is None:
-        enddate = datetime.datetime.now()
     else:
-        enddate = pd.to_datetime(enddate)
-
+        startdate = pd.to_datetime("1901-01-01")
+    enddate = pd.to_datetime(enddate) if enddate else datetime.datetime.now()
     station = station.split(":")[-1]
-
     urls = []
     for year in range(startdate.year, enddate.year + 1):
-        urls.append(baseurl.format(**locals()))
+        url = baseurl.format(station=station, year=year)
+        urls.append(url)
 
     with Pool(processes=os.cpu_count()) as pool:
         # have your pool map the file names to dataframes
@@ -155,97 +193,23 @@ def file_downloader(baseurl, station, startdate=None, enddate=None):
     return final[startdate:enddate]
 
 
-@tsutils.transform_args(start_date=pd.to_datetime, end_date=pd.to_datetime)
-def pdap(
-    url,
-    lat,
-    lon,
-    latitude_name="lat",
-    longitude_name="lon",
-    time_name="time",
-    variables=None,
-    start_date=None,
-    end_date=None,
-    timeout=30,
-):
-
-    import numpy as np
-    from haversine import haversine_vector
-
-    if "dods" in url:
-        dataset = open_dods(url, timeout=timeout)
-    else:
-        dataset = open_url(url, timeout=timeout)
-
-    # Determine rlat and rlon index in the grid closest to target (lat, lon).
-    lat_vals = dataset[latitude_name][:].data
-    lon_vals = dataset[longitude_name][:].data
-
-    nlat, nlon = np.meshgrid(lat_vals, lon_vals)
-
-    nlat = nlat.flatten()
-    nlon = nlon.flatten()
-
-    ngrid = list(zip(nlat, nlon))
-    distances = haversine_vector([(lat, lon)], ngrid, comb=True)
-    closest = np.argmin(distances)
-
-    rlat = int(np.argmax(lat_vals == nlat[closest]))
-    rlon = int(np.argmax(lon_vals == nlon[closest]))
-
-    # Get the start_data and end_date squared away.
-    from coards import parse
-
-    dtunits = dataset[time_name].attributes["units"]
-    datetimes = pd.DatetimeIndex(
-        [parse(value, dtunits) for value in dataset["time"][:].data]
-    )
-
-    datetimes = datetimes[start_date:end_date]
-
-    # Determine the variable list.
-    allvars = list(dataset.keys())
-    allvars.remove(latitude_name)
-    allvars.remove(longitude_name)
-    allvars.remove(time_name)
-
-    if variables is None:
-        variables = allvars
-    else:
-        variables = tsutils.make_list(variables)
-        for var in variables:
-            if var not in allvars:
-                raise ValueError(
-                    tsutils.error_wrapper(
-                        f"""
-The variable "{var}" is not available.  The available variables are "{allvars}".
-"""
-                    )
-                )
-
-    df = pd.DataFrame()
-    for dfvar in variables:
-        ndf = pd.DataFrame(
-            dataset[dfvar][start_date:end_date, rlat, rlon].data, index=datetimes
-        )
-        df = df.join(ndf, how="outer")
-    return df
-
-
-def dapdownloader(url, lat, lon, var, time_name="date", start_date=None, end_date=None):
-    ncss = NCSS(url)
-
+def dapdownloader(url: str, lat, lon, var, start_date=None, end_date=None):
+    """Download data from a OpenDAP server using NCSS."""
+    for u in tsutils.make_list(url):
+        with contextlib.suppress(xml.etree.ElementTree.ParseError):
+            ncss = NCSS(u.format(**locals()))
+            break
     avail_vars = list(ncss.variables)
     var = tsutils.make_list(var)
+    lat = tsutils.make_list(lat)
+    lon = tsutils.make_list(lon)
 
     if not var:
         var = avail_vars
     else:
         nvar = []
         for i in avail_vars:
-            for j in var:
-                if i.lower() == j.lower():
-                    nvar.append(i)
+            nvar.extend(i for j in var if i.lower() == j.lower())
         var = nvar
 
     query = ncss.query()
@@ -254,15 +218,13 @@ def dapdownloader(url, lat, lon, var, time_name="date", start_date=None, end_dat
         start_date = datetime.datetime(1, 1, 1)
     if end_date is None:
         end_date = datetime.datetime(9999, 1, 1)
-
-    if (start_date is None) and (end_date is None):
-        query.all_times()
-    else:
-        query.time_range(start_date, end_date)
-
+    query.time_range(start_date, end_date)
     query.variables(*var)
 
-    query.lonlat_point(lon, lat)
+    if len(lon) == 2 and len(lat) == 2:
+        query.lonlat_box(lon[0], lon[1], lat[0], lat[1])
+    else:
+        query.lonlat_point(lon[0], lat[0])
 
     ncss.validate_query(query)
 
@@ -270,8 +232,6 @@ def dapdownloader(url, lat, lon, var, time_name="date", start_date=None, end_dat
 
     # Sometimes the variable name is different.  Remove all the other keys to
     # arrive at the variable name.
-    data_keys = list(data.keys())
-    # data_keys.remove(time_name)
 
     ndf = pd.DataFrame()
     for v in var:
@@ -302,7 +262,7 @@ def dapdownloader(url, lat, lon, var, time_name="date", start_date=None, end_dat
     return ndf
 
 
-@typic.al
+@validate_call
 def opendap(
     url: str,
     lat: float,
@@ -311,19 +271,16 @@ def opendap(
     variables=None,
     start_date=None,
     end_date=None,
-    tzname="UTC",
     time_name="date",
     missing_value=None,
     lat_name="lat",
     lon_name="lon",
-    user_charset="ascii",
     single_var_url=False,
+    tzname="UTC",
 ):
-    from haversine import haversine_vector
-
+    """Read data from a OpenDAP server using pydap."""
     if variables is None:
-        variables = list(variable_map.keys())
-        variables.sort()
+        variables = sorted(variable_map.keys())
     else:
         variables = tsutils.make_list(variables)
         for variable in variables:
@@ -331,11 +288,16 @@ def opendap(
                 raise ValueError(
                     tsutils.error_wrapper(
                         f"""
-The variable "{variable}" is not available from this service.  The available
-variables are "{variables_map.keys()}"."""
+                        The variable "{variable}" is not available from this
+                        service.  The available variables are
+                        "{variable_map.keys()}".
+                        """
                     )
                 )
 
+    # Need to download lat and lon data to determine the closest grid point.
+    # If the url is a single variable url, it doesn't matter which variable is
+    # used to download the lat and lon data.  So use the first.
     if single_var_url is True:
         dataset = open_url(url.format(variables[0]))
     else:
@@ -366,15 +328,18 @@ variables are "{variables_map.keys()}"."""
         except KeyError:
             ds = dataset[variable_map[var]["standard_name"]]
 
-        scale_factor = ds.attributes.get("scale_factor", 1.0)
-        add_offset = ds.attributes.get("add_offset", 0.0)
-        missing_value = ds.attributes.get("missing_value", missing_value)
-        long_name = ds.attributes.get("long_name", "missing_long_name")
+        # EXAMPLE CONTENTS OF TYPICAL ds.attributes
+        # ds.attributes.units: mm
+        # ds.attributes.description: Daily Accumulated Precipitation
+        # ds.attributes.long_name: pr
+        # ds.attributes.standard_name: pr
+        # ds.attributes.dimensions: lon lat time
+        # ds.attributes.grid_mapping: crs
+        # ds.attributes.coordinate_system: WGS84,EPSG:4326
 
-        units = ds.attributes["units"]
         # The following normalizes the units string to conform to the 'pint'
         # library.
-        units = units.replace(" per ", "/")
+        units = ds.attributes.get("units", "").replace(" per ", "/")
         units = units.replace("millimeters", "mm")
         units = units.replace("square meter", "m^2")
         units = units.replace("meters", "m")
@@ -387,10 +352,12 @@ variables are "{variables_map.keys()}"."""
 
         time = dataset[time_name]
         try:
+            time_units = time.attributes.get("units", "")
+            calendar = time.attributes.get("calendar", "standard")
             time = cftime.num2pydate(
                 time.data[:],
-                units=time.attributes["units"],
-                calendar=time.attributes.get("calendar", "standard"),
+                units=time_units,
+                calendar=calendar,
             )
         except ValueError:
             # If the dates are byte strings b"2001-01-01"...
@@ -403,16 +370,16 @@ variables are "{variables_map.keys()}"."""
         if start_date is None:
             start_date_index = None
         else:
-            start_date_index = timedfindex.get_loc(
-                pd.to_datetime(start_date), method="nearest"
-            )
+            start_date_index = timedfindex.get_indexer(
+                [pd.to_datetime(start_date)], method="nearest"
+            )[0]
 
         if end_date is None:
             end_date_index = None
         else:
-            end_date_index = timedfindex.get_loc(
-                pd.to_datetime(end_date), method="nearest"
-            )
+            end_date_index = timedfindex.get_indexer(
+                [pd.to_datetime(end_date)], method="nearest"
+            )[0]
 
         try:
             point = ds.array[
@@ -428,7 +395,9 @@ variables are "{variables_map.keys()}"."""
         )
 
         df[df == missing_value] = pd.NA
-        df = df * scale_factor + add_offset
+        df = df * ds.attributes.get("scale_factor", 1.0) + ds.attributes.get(
+            "add_offset", 0.0
+        )
 
         df.columns = [f"{variable_map[var]['lname']}:{units}"]
         ndf = ndf.join(df, how="outer")
@@ -441,31 +410,39 @@ variables are "{variables_map.keys()}"."""
         raise ValueError(
             tsutils.error_wrapper(
                 f"""
-No data is available for lat/lon "{lat}/{lon}" and variables "{variables}"
-between {start_date} and {end_date}.
-"""
+                No data is available for lat/lon "{lat}/{lon}" and variables
+                "{variables}" between {start_date} and {end_date}.
+                """
             )
         )
+    try:
+        ndf.index = ndf.index.tz_localize(tzname)
+    except TypeError:
+        ndf.index = ndf.index.tz_convert(tzname)
+
+    ndf.index.name = f"Datetime:{tzname}"
 
     return ndf
 
 
-def eopendap(
+def erddap(
     url,
     lat,
     lon,
     variables=None,
-    variable_map=None,
     start_date=None,
     end_date=None,
-    tzname="UTC",
     time_name="date",
-    missing_value=None,
+    single_var_url=False,
 ):
+    """Download data from an ERDDAP server."""
     variables = tsutils.make_list(variables)
 
     from erddapy import ERDDAP
 
+    if single_var_url is True:
+        url = url.format(variables[0])
+
     e = ERDDAP(
         server=url,
         protocol="opendap",
@@ -481,28 +458,47 @@ def eopendap(
         "longitude<=": lon,
     }
 
-    df = e.to_pandas(
+    return e.to_pandas(
         index_col=time_name,
         parse_dates=True,
     ).dropna()
 
-    return df
-
 
+# Uses NCSS and is slow...
 def nopendap(
     url,
     lat,
     lon,
+    variable_map,
     variables=None,
-    variable_map=None,
     start_date=None,
     end_date=None,
     tzname="UTC",
     time_name="date",
     missing_value=None,
+    single_var_url=False,
 ):
+    """Download data from a OPeNDAP server using NCSS."""
     variables = tsutils.make_list(variables)
 
+    if single_var_url is True:
+        cdf = pd.DataFrame()
+        for var in variables:
+            rdf = opendap(
+                url.format(var),
+                lat,
+                lon,
+                variable_map,
+                variables=None,
+                start_date=start_date,
+                end_date=end_date,
+                time_name=time_name,
+                missing_value=missing_value,
+                single_var_url=False,
+            )
+            cdf = cdf.join(rdf, how="outer")
+        return cdf
+
     ncss = NCSS(url)
 
     avail_vars = list(ncss.variables)
@@ -513,9 +509,7 @@ def nopendap(
     else:
         nvar = []
         for i in avail_vars:
-            for j in var:
-                if i.lower() == j.lower():
-                    nvar.append(i)
+            nvar.extend(i for j in var if i.lower() == j.lower())
         var = nvar
 
     query = ncss.query()
@@ -544,9 +538,10 @@ def nopendap(
         try:
             vmap = variable_map[v]
         except KeyError:
-            vmap = {}
-            for key, value in variable_map.items():
-                vmap[variable_map[key]["lname"]] = value
+            vmap = {
+                variable_map[key]["lname"]: value for key, value in variable_map.items()
+            }
+
             vmap = vmap[v]
         standard_name = vmap["standard_name"]
         lname = vmap["lname"]
@@ -593,9 +588,9 @@ def nopendap(
         raise ValueError(
             tsutils.error_wrapper(
                 f"""
-Returned no data for lat/lon "{lat}/{lon}", variables
-"{variables}" between {start_date} and {end_date}.
-"""
+                Returned no data for lat/lon "{lat}/{lon}", variables
+                "{variables}" between {start_date} and {end_date}.
+                """
             )
         )
 
